@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.dao;
@@ -33,7 +33,7 @@ import javax.ejb.RemoveException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.bean.JobConstant;
+import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.commons.util.ConnectionManager;
 import com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoBean;
 import com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoPK;
@@ -48,40 +48,42 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoPK;
  * @see com.clustercontrol.jobmanagement.dao.JobStartInfoDAO
  */
 public class JobStartInfoDAOImpl implements JobStartInfoDAO {
-	
+
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog(JobStartInfoDAOImpl.class);
-	
+	private static Log m_log = LogFactory.getLog(JobStartInfoDAOImpl.class);
+
+	@Override
 	public void init() {
 	}
-	
-	/** 
+
+	/**
 	 * SELECT文を発行します。
 	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoBean)
 	 */
+	@Override
 	public void load(JobStartInfoPK pk, JobStartInfoBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_start_info WHERE session_id = ? AND job_id = ? and jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				//取得した値をBeanにセット
 				ejb.setCalendar(res.getInt("calendar"));
@@ -149,21 +151,22 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 		}
 		m_log.debug("load() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * UPDATE文を発行します。
 	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoBean)
 	 */
+	@Override
 	public void store(JobStartInfoBean ejb) throws EJBException {
 		m_log.debug("store() start : " + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
@@ -207,10 +210,10 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			sql.append("WHERE session_id = ? AND ");
 			sql.append("job_id = ? ");
 			sql.append("AND jobunit_id = ?");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setInt(1, ejb.getCondition_type());
 			stmt.setInt(2, ejb.getSuspend());
 			stmt.setInt(3, ejb.getSkip());
@@ -249,20 +252,20 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			stmt.setString(36, ejb.getSession_id());
 			stmt.setString(37, ejb.getJob_id());
 			stmt.setString(38, ejb.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("store() error : " + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + msg);
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : " + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+					+ ", jobunitId=" + ejb.getJobunit_id()
+					+ ", jobId=" + ejb.getJob_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクローズ
@@ -275,8 +278,8 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("store() error : " + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -284,41 +287,42 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
 	}
-	
+
 	/**
 	 * DELETE文を発行します。
 	 * 引数で指定されたプライマリキーでデータベースから削除します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoPK)
 	 */
+	@Override
 	public void remove(JobStartInfoPK pk) throws RemoveException, EJBException {
 		m_log.debug("remove() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "DELETE FROM cc_job_start_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1 ) {
 				String msg = "result row is not 1";
 				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
-				throw new EJBException(msg);	
+				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
-			
+
 		} finally {
 			try {
 				if(stmt != null){
@@ -334,18 +338,19 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 		}
 		m_log.debug("remove() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * INSERT文を発行します。
 	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoBean)
 	 */
+	@Override
 	public JobStartInfoPK create(JobStartInfoBean ejb) throws CreateException, EJBException {
 		m_log.debug("create() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
 				+ ", jobId=" + ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		JobStartInfoPK pk;
@@ -393,10 +398,10 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			sql.append("end_delay_operation_end_value, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getSession_id());
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setInt(3, ejb.getCondition_type());
@@ -435,25 +440,25 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			stmt.setInt(36, ejb.getEnd_delay_operation_type());
 			stmt.setInt(37, ejb.getEnd_delay_operation_end_value());
 			stmt.setString(38, ejb.getJobunit_id());
-			
+
 			int row =	stmt.executeUpdate();
 			pk = new JobStartInfoPK(
 					ejb.getSession_id(),
 					ejb.getJobunit_id(),
 					ejb.getJob_id());
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -467,8 +472,8 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -477,7 +482,7 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 				+ ", jobId=" + ejb.getJob_id());
 		return pk;
 	}
-	
+
 	/**
 	 * 全件取得するSELECT文を発行します。
 	 * 取得したデータのプライマリキーをコレクションに格納し返します。
@@ -485,22 +490,23 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartInfoDAO#findAll()
 	 */
+	@Override
 	public Collection findAll() throws FinderException {
 		m_log.debug("findAll() start : ");
-		
+
 		ArrayList<JobStartInfoPK> ret = new ArrayList<JobStartInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_start_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobStartInfoPK pk= new JobStartInfoPK(
 						res.getString("session_id"),
@@ -509,7 +515,7 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
@@ -530,7 +536,7 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 		m_log.debug("findAll() end : ");
 		return ret;
 	}
-	
+
 	/**
 	 * 1件取得するSELECT文を発行します。
 	 * 引数で指定されたプライマリキーで、データベースを検索します。
@@ -538,26 +544,27 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobStartInfoPK)
 	 */
+	@Override
 	public JobStartInfoPK findByPrimaryKey(JobStartInfoPK pk) throws FinderException {
 		m_log.debug("findByPrimaryKey() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_start_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				return pk;
 			} else {
@@ -583,7 +590,7 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
 		}
 	}
-	
+
 	/**
 	 * ジョブ待ち条件情報をジョブ待ち条件マスタから作成します。
 	 * 
@@ -596,17 +603,17 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 	 */
 	public void makeSession(String sessionId, String jobunitId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
-		Connection conn=null; 
+
+		Connection conn=null;
 		Connection connMaster = null;
 		PreparedStatement stmt=null;
 		PreparedStatement stmtMaster= null;
 		String jobId = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_start_info (");
@@ -647,14 +654,14 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			sql.append("end_delay_operation, ");
 			sql.append("end_delay_operation_type, ");
 			sql.append("end_delay_operation_end_value, ");
-			sql.append("jobunit_id) ");			
+			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1,sessionId);
 			stmt.setString(38, jobunitId);
-			
+
 			//SQL文の定義(マスタ検索)
 			StringBuilder sqlMaster = new StringBuilder();
 			sqlMaster.append("SELECT ");
@@ -702,33 +709,33 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			sqlMaster.append("AND cc_job_mst.job_id= ? ");
 			sqlMaster.append("AND cc_job_mst.jobunit_id= ? ");
 			sqlMaster.append(")");
-			
+
 			m_log.debug("makeSession() sqlMaster : sql=" + sqlMaster.toString());
-			
+
 			//SQL文のセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sqlMaster.toString());
-			
+
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
 				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
 				String parentJobId = (String)ht.get("parentJobId");
-				
+
 				//SQL文のセット(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				stmtMaster.setString(2, jobunitId);
-				
+
 				//SQL実行(マスタ検索)
 				ResultSet resMaster = stmtMaster.executeQuery();
-				
+
 				if (resMaster.next()) {
 					//ジョブネット・ジョブ・ファイル転送ジョブの場合
 					if(parentJobId.compareTo("TOP") !=0  &&
 							(resMaster.getInt("job_type") == JobConstant.TYPE_JOBNET ||
 									resMaster.getInt("job_type") == JobConstant.TYPE_JOB||
 									resMaster.getInt("job_type") == JobConstant.TYPE_FILEJOB)){
-						
+
 						//SQL文のセット(INSERT)
 						stmt.setString(2, resMaster.getString("job_id"));
 						stmt.setInt(3, resMaster.getInt("condition_type"));
@@ -766,8 +773,8 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 						stmt.setInt(35, resMaster.getInt("end_delay_operation"));
 						stmt.setInt(36, resMaster.getInt("end_delay_operation_type"));
 						stmt.setInt(37, resMaster.getInt("end_delay_operation_end_value"));
-						
-						
+
+
 						//INSERTを実行
 						int row =	stmt.executeUpdate();
 						if (row != 1) {
