@@ -47,6 +47,7 @@ import com.clustercontrol.http.factory.DeleteMonitorHttp;
 import com.clustercontrol.http.factory.ModifyMonitorHttp;
 import com.clustercontrol.http.factory.ModifyMonitorHttpString;
 import com.clustercontrol.http.factory.SelectMonitorHttp;
+import com.clustercontrol.logfile.ejb.session.MonitorLogfileControllerBean;
 import com.clustercontrol.logfile.factory.AddMonitorLogfileString;
 import com.clustercontrol.logfile.factory.DeleteMonitorLogfile;
 import com.clustercontrol.logfile.factory.ModifyMonitorLogfileString;
@@ -293,6 +294,10 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 						tm.commit();
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
 							SystemlogCache.clear();
+						} else if (HinemosModuleConstant.MONITOR_CUSTOM.equals(monitorTypeId)) {
+							SelectCustom.clearCustomCache();
+						} else if (HinemosModuleConstant.MONITOR_LOGFILE.equals(monitorTypeId)) {
+							MonitorLogfileControllerBean.clearLogfileCache();
 						}
 					} else {
 						tm.rollback();
@@ -463,6 +468,10 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 						tm.commit();
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
 							SystemlogCache.clear();
+						} else if (HinemosModuleConstant.MONITOR_CUSTOM.equals(monitorTypeId)) {
+							SelectCustom.clearCustomCache();
+						} else if (HinemosModuleConstant.MONITOR_LOGFILE.equals(monitorTypeId)) {
+							MonitorLogfileControllerBean.clearLogfileCache();
 						}
 					} else {
 						tm.rollback();
@@ -585,6 +594,10 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 						tm.commit();
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
 							SystemlogCache.clear();
+						} else if (HinemosModuleConstant.MONITOR_CUSTOM.equals(monitorTypeId)) {
+							SelectCustom.clearCustomCache();
+						} else if (HinemosModuleConstant.MONITOR_LOGFILE.equals(monitorTypeId)) {
+							MonitorLogfileControllerBean.clearLogfileCache();
 						}
 					} else {
 						tm.rollback();
