@@ -1,22 +1,21 @@
 /*
-                                                                                                
+
 Copyright (C) 2008 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.poller;
 
 import java.lang.reflect.Constructor;
-import java.text.ParseException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -31,13 +30,8 @@ import javax.rmi.PortableRemoteObject;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.quartz.CronTrigger;
-import org.quartz.JobDetail;
-import org.quartz.Scheduler;
-import org.quartz.SchedulerException;
-import org.quartz.impl.StdScheduler;
 
-import com.clustercontrol.FacilityNotFoundException;
+import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.factory.NodeProperty;
 import com.clustercontrol.sharedtable.DataTable;
@@ -48,46 +42,66 @@ import com.clustercontrol.vm.ejb.entity.VmMethodMstLocal;
 import com.clustercontrol.vm.ejb.entity.VmMethodMstPK;
 import com.clustercontrol.vm.ejb.entity.VmMethodMstUtil;
 import com.clustercontrol.vm.VmPollerImplInterface;
-import com.clustercontrol.bean.PollerProtocolConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.commons.scheduler.TriggerConstant;
+import com.clustercontrol.commons.scheduler.TriggerSchedulerException;
+import com.clustercontrol.commons.scheduler.TriggerSchedulerFactory;
+import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.poller.bean.PollerProtocolConstant;
+import com.clustercontrol.poller.ejb.session.PollingJobBean;
+import com.clustercontrol.poller.ejb.session.PollingJobUtil;
+import com.clustercontrol.poller.impl.SnmpBulkPollerImpl;
 import com.clustercontrol.poller.impl.SnmpPollerImpl;
 import com.clustercontrol.poller.impl.WbemPollerImpl;
-import com.clustercontrol.poller.job.PollingJob;
 
 public class PollingController {
 	private static Log m_log = LogFactory.getLog( PollingController.class );
-	
+
 	private Object modifyLock = new Object();
 
-	private final static String SHARED_TABLE_JNDI_NAME = "SharedTable";
-	private final static String POLLER_MANAGER_JNDI_NAME = "PollerManager";
-	
+	public final static String SHARED_TABLE_JNDI_NAME = "SharedTable";
+	public final static String POLLER_MANAGER_JNDI_NAME = "PollerManager";
+
 	private final static int RUNNING = 1;
 	private final static int STOPPED = 2;
-	
-	private final String m_quartzJndiName = "QuartzRAM";
+
+	private final String m_quartzJndiName = "RAMScheduler";
 	private final String m_quartzJobName;  // ポーラ名とする
 	private final String m_quartzGroupName;  // ポーラグループとする
-	
+
 	private final String m_pollerGroup;
 	private final String m_pollerName;
-	
+
 	private final String m_targetFacilityId;
-	
+
 	private final PollingControllerConfig m_pollingConfig;
-	
+
 	private final String m_tableGroup;
 	private final String m_tableName;
-	
+
 	// ポーラの状態を示す
 	volatile private int m_status;
-	
-	public PollingController(
-			String pollerGroup, 
-			String pollerName, 
+
+	// SNMP BULKを利用するフラグ。
+	private static boolean snmpBulkFlag = false;
+	static {
+		String key = "poller.snmp.bulk.flag";
+		try {
+			String str = HinemosProperties.getProperty(key);
+			if (str != null && "true".equals(str)) {
+				snmpBulkFlag = true;
+			}
+		} catch (Exception e) {
+			m_log.warn(key + " is not available. " + e.getMessage());
+		}
+	}
+
+	protected PollingController(
+			String pollerGroup,
+			String pollerName,
 			String targetFacilityId,
 			boolean indexCheckFlg,
-			String tableGroup, 
+			String tableGroup,
 			String tableName)
 	throws NotInitializedException, DataTableNotFoundException{
 		m_pollerGroup = pollerGroup;
@@ -98,14 +112,14 @@ public class PollingController {
 		m_tableName = tableName;
 
 		m_quartzJobName = m_pollerName;
-		m_quartzGroupName = m_pollerGroup;
-		
+		m_quartzGroupName = m_pollerGroup + "_POLLER";
+
 		m_status = PollingController.STOPPED;
-		
+
 		try {
 			// 書き込み対象テーブルが存在するか否かを確認する
 			SharedTable sharedTable = lookupSharedTable();
-			
+
 			if(!sharedTable.containsDataTable(tableGroup, tableName)){
 				// テーブルが存在しないため例外を投げる
 				throw new DataTableNotFoundException(tableGroup, tableName);
@@ -116,109 +130,67 @@ public class PollingController {
 					"Table is not initialized. (" + tableName + " in " + tableGroup + " )");
 		}
 	}
-	
-	protected void scheduleJob(){
+
+	private void scheduleJob(){
+		m_log.debug("scheduleJob()");
+
 		// 収集間隔を取得する
 		int interval = m_pollingConfig.getMinPollingInterval();
 
 		// デバッグ出力
 		m_log.debug("scheduleJob : " + interval);
-		
-		//QuartzのSchedulerをルックアップ
-		Scheduler scheduler = null;
-		try {
-			InitialContext ctx = new InitialContext();
-			Object obj = ctx.lookup(m_quartzJndiName);
-			scheduler = (Scheduler)PortableRemoteObject.narrow(obj, StdScheduler.class);
 
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
-		}
-		
-		// スケジューラの取得に失敗した場合は終了
-		if(scheduler == null){
-			return;
-		}
-		
 		// 収集間隔が-1の場合は新規に登録しない
 		if(interval == -1){
 			try {
 				// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
-				scheduler.deleteJob(m_quartzJobName, m_quartzGroupName);
+				TriggerSchedulerFactory.getScheduler(TriggerConstant.POLLER_INSTANCE_NAME).deleteJob(
+						m_quartzJobName,
+						m_quartzGroupName);
 
 				// ステータス変更
 				m_status = PollingController.STOPPED;
-			} catch (SchedulerException e) {
+			} catch (TriggerSchedulerException e) {
 				m_log.error(e.getMessage(), e);
 			}
 			return;
 		}
-		
-		// 新規にジョブを生成
-		JobDetail job = new JobDetail(m_quartzJobName, m_quartzGroupName, PollingJob.class);
-		//ジョブ完了時に削除されないようにする
-		job.setDurability(true);
-		
-		//JobDetailに変数を設定
-		job.getJobDataMap().put("jndiName", POLLER_MANAGER_JNDI_NAME);
-		job.getJobDataMap().put("pollerGroup", m_pollerGroup);
-		job.getJobDataMap().put("pollerName", m_pollerName);
-		
-		
-		//CronTriggerを作成
-		CronTrigger cronTrigger = new CronTrigger(m_quartzJobName, m_quartzGroupName);
 
-		//起動失敗した場合は、次の起動予定時刻をセットするように設定
-		cronTrigger.setMisfireInstruction(CronTrigger.MISFIRE_INSTRUCTION_DO_NOTHING);
+		// CronTrigger でジョブをスケジューリング登録
+		try{
+			// EJBアクセス引数を定義する
+			Object[] jdArgs = new Object[3];
+			Class[] jdArgsType = new Class[3];
+			jdArgs[0] = POLLER_MANAGER_JNDI_NAME;
+			jdArgsType[0] = String.class;
+			jdArgs[1] = m_pollerGroup;
+			jdArgsType[1] = String.class;
+			jdArgs[2] = m_pollerName;
+			jdArgsType[2] = String.class;
 
-		try {
 			String cronString = PollingInterval.parseCronExpression(interval);
-			cronTrigger.setCronExpression(cronString);
-		} catch (ParseException e) {
-			// エラー処理
-			m_log.error(e.getMessage(), e);
-		}
-		
-
-		try {
-			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
-			scheduler.deleteJob(m_quartzJobName, m_quartzGroupName);
-
-			// ジョブを登録する
-			scheduler.scheduleJob(job, cronTrigger);
-
-			// ジョブを実行する
-			scheduler.triggerJob(m_quartzJobName, m_quartzGroupName);
-			
-			// ステータス変更
-			m_status = PollingController.RUNNING;
-		} catch (SchedulerException e) {
-			// エラー処理
-			m_log.error(e.getMessage(), e);
-		}
-	}
-	
-	protected void polling(){
-		try {
-			//QuartzのSchedulerをルックアップ
-			InitialContext ctx = new InitialContext();
-			Object obj = ctx.lookup(m_quartzJndiName);
-			Scheduler scheduler = (Scheduler)PortableRemoteObject.narrow(obj, StdScheduler.class);
-
-			// ジョブを実行する
-			scheduler.triggerJob(m_quartzJobName, m_quartzGroupName);
-			
-			// ステータス変更
-			m_status = PollingController.RUNNING;
-		} catch (SchedulerException e) {
-			// エラー処理
-			m_log.error(e.getMessage(), e);
+			if(cronString == null){
+				m_log.error("Illegal argument : interval = " + interval);
+			} else {
+				TriggerSchedulerFactory.getScheduler(TriggerConstant.MONITOR_INSTANCE_NAME).scheduleEjbLocalInvokerJobWithCronTrigger(
+						m_quartzJobName,
+						m_quartzGroupName,
+						PollingJobUtil.getLocalHome(),
+						PollingJobBean.METHOD_NAME,
+						jdArgs,
+						jdArgsType,
+						null,
+						true,
+						true,
+						cronString);
+			}
+		} catch (TriggerSchedulerException e) {
+			m_log.warn("scheduleJob() : pollerGroup = " + m_pollerGroup + ", pollerName = " + m_pollerName + ", " + e.getMessage(), e);
 		} catch (NamingException e) {
-			// エラー処理
-			m_log.error(e.getMessage(), e);
+			m_log.warn("scheduleJob() : pollerGroup = " + m_pollerGroup + ", pollerName = " + m_pollerName + ", " + e.getMessage(), e);
 		}
 	}
-	
+
 	/**
 	 * ポーリングを開始する
 	 * 既に指定の収集名が登録されている場合は設定を上書きする（ver3.2以降）
@@ -230,15 +202,17 @@ public class PollingController {
 	 */
 	public void startPolling(
 			String collectorName,
-			int interval, 
+			int interval,
 			HashMap<String, List<String>> maps)
 	throws CollectorAlreadyExistException{
+		m_log.debug("startPolling() collectorName = " + collectorName + ", interval = " + interval);
+
 		synchronized (modifyLock) {
 			// 指定の収集名が既に登録されている場合も、上書きする（ver3.2より）
 			if(m_pollingConfig.containsCollectorName(collectorName)){
 				m_log.debug(collectorName + "is already exist.");
-//				// 既に収集名が設定されているため例外を投げる
-//				throw new CollectorAlreadyExistException(collectorName);
+				//				// 既に収集名が設定されているため例外を投げる
+				//				throw new CollectorAlreadyExistException(collectorName);
 			}
 
 			try {
@@ -256,7 +230,7 @@ public class PollingController {
 				m_log.error(e.getMessage(), e);
 				return;
 			}
-			
+
 			// 指定の収集名で、収集間隔、収集プロトコルとポーリング対象のマップを登録する
 			m_pollingConfig.putPollingTargets(collectorName, interval, maps);
 
@@ -268,7 +242,7 @@ public class PollingController {
 	/**
 	 * ポーリングを終了する
 	 * @param collectorName 収集名
-	 * @throws FacilityNotFoundExceptionBK
+	 * @throws FacilityNotFoundBK
 	 */
 	public void stopPolling(String collectorName){
 		synchronized (modifyLock) {
@@ -288,7 +262,7 @@ public class PollingController {
 
 				stable.unregisterCollector(m_tableGroup, m_tableName, collectorName);
 			} catch (DataTableNotFoundException e) {
-				m_log.error(e.getMessage(), e);
+				m_log.warn(e.getMessage(), e);
 				return;
 			} catch (NamingException e) {
 				m_log.error(e.getMessage(), e);
@@ -296,10 +270,10 @@ public class PollingController {
 			}
 		}
 	}
-	
+
 	/**
 	 * 全ての収集名のポーリングを終了する
-	 * @throws FacilityNotFoundExceptionBK
+	 * @throws FacilityNotFoundBK
 	 */
 	public void stopPollingAll(){
 		synchronized (modifyLock) {
@@ -324,15 +298,15 @@ public class PollingController {
 				return;
 			}
 		}
-	}	
-	
+	}
+
 	/**
 	 * ポーリングを実行する
 	 */
 	public void run() {
 		// デバッグログ出力
 		m_log.debug("run start : " + m_pollerGroup + "  " + m_pollerName);
-	
+
 		SharedTable sharedTable = null;
 		// 収集値格納用テーブルをルックアップ
 		try {
@@ -345,36 +319,28 @@ public class PollingController {
 		} catch (NamingException e) {
 			m_log.error(e.getMessage(), e);
 		}
-		
+
 		try {
-			/* ポーリングしても意味のないポーリング対象がないかチェックする */
 
-			/* ポーラが管理している収集名のうち、書き込み対象である共有テーブルでは
-			 * 既に参照対象でなくなっている収集名を特定する */
-			
-			// 共有テーブルで参照される収集名のセットを取得
-			Set<String> retainCollectorNames = 
+			Set<String> stCollectorNames =
 				new HashSet<String>(sharedTable.getCollectorNames(m_tableGroup, m_tableName));
+			for(String collectorName : stCollectorNames){
+				if(m_pollingConfig.containsCollectorName(collectorName)){
+					m_log.debug("run : " + m_pollerGroup + "  " + m_pollerName + " : " + collectorName + " is exist");
+				}else{
+					m_log.warn("run : " + m_pollerGroup + "  " + m_pollerName + " : " + collectorName + " is not exist");
+				}
+			}
 
-			// ポーラで保持している収集名のセットを取得
-			Set<String> pollerCollectorNames = m_pollingConfig.getCollectorNames();
-			
-			// 共通要素を抽出
-			retainCollectorNames.retainAll(pollerCollectorNames);
-			
-			// 削除対象の収集名
-			Set<String> removeCollectoName = 
+			Set<String> pcCollectoName =
 				new HashSet<String>(m_pollingConfig.getCollectorNames());
-			removeCollectoName.removeAll(retainCollectorNames);
-			
+			pcCollectoName.removeAll(stCollectorNames);
 			synchronized (modifyLock) {
-				Iterator<String> itr = removeCollectoName.iterator();
-				
+
 				boolean modifyFlg = false;
-				while(itr.hasNext()){
-					String collectorName = itr.next();
+				for(String collectorName : pcCollectoName){
 					// 指定の収集名で、収集間隔、ポーリング対象のリストを削除する
-					modifyFlg = m_pollingConfig.removePollingTargets(collectorName);
+					modifyFlg = modifyFlg | m_pollingConfig.removePollingTargets(collectorName);
 				}
 
 				// 最小収集間隔が変更されている場合はスケジューリング
@@ -382,6 +348,7 @@ public class PollingController {
 					scheduleJob();
 				}
 			}
+
 		} catch (DataTableNotFoundException e) {
 			m_log.error(e.getMessage(), e);
 			// 書き込み対象テーブルを取得できないため終了する
@@ -397,21 +364,21 @@ public class PollingController {
 			// 書き込み対象テーブルを取得できないため終了する
 			return;
 		}
-	
+
 		// 更新すべきテーブルがない場合は処理終了
 		if(holderIntervals.size() <= 0){
 			return;
-		}		
-	
+		}
+
 		// 現在時刻を取得
 		long now = System.currentTimeMillis();
 
 		// 今のタイミングで更新すべきテーブルを特定するため、
 		// 更新の必要のある収集間隔のリストを取得する
 		List<Integer> intervals = m_pollingConfig.getCurrentRefreshIntervals(now);
-	
+
 		ArrayList<Integer> tmpList = new ArrayList<Integer>(intervals);
-	
+
 		// 全エンティティ内を調べるループをまわすためテンポラリのリストを作成
 		Iterator<Integer> itr = tmpList.iterator();
 		while(itr.hasNext()){
@@ -422,29 +389,29 @@ public class PollingController {
 				intervals.remove(new Integer(interval));
 			}
 		}
-	
+
 		// 更新すべきテーブルがない場合は処理終了
 		if(intervals.size() <= 0){
 			return;
 		}
-	
+
 		// ポーリング対象の中から今のタイミングで収集すべきものを抽出する
 		HashMap<String, List<String>> pollingTargetMap = m_pollingConfig.getCurrentTargetMap(now);
-	
+
 		m_log.debug("run() pollingTargetMap : " + pollingTargetMap);
 		// 収集すべきポーリング対象がない場合は処理終了
 		if(pollingTargetMap.size() <= 0){
 			m_log.debug("polling targets are nothing.");
 			return;
 		}
-		
+
 		// ポーリングにより取得した値を格納するテーブル
 		DataTable dataTable = null;
-		
+
 		NodeInfo nodeInfo = null;
 		try {
 			nodeInfo = NodeProperty.getProperty(m_targetFacilityId);
-		} catch (FacilityNotFoundException e1) {
+		} catch (FacilityNotFound e1) {
 			m_log.warn("facility not found 1. FacilityId = " + m_targetFacilityId);
 			// ポーリングは実行しない
 			// 取得値が空のテーブルを作成する
@@ -472,7 +439,7 @@ public class PollingController {
 			dataTable = polling(nodeInfo, pollingTargetMap, -1, -1);
 		}
 		m_log.debug("dataTable" + dataTable);
-		
+
 		// 収集値を共有テーブルに格納する
 		for(int interval : intervals){
 			// 新規収集した情報をテーブルの先頭に挿入する
@@ -483,33 +450,31 @@ public class PollingController {
 				// 変更前と変更後の収集値が同じテーブルホルダに格納されることを防ぐ
 				sharedTable.insertDataTable(
 						m_tableGroup,
-						m_tableName, 
-						interval, 
+						m_tableName,
+						interval,
 						dataTable,
 						nodeInfo.getAvailableIpAddress());
 			} catch (DataTableNotFoundException e) {
 				m_log.error(e.getMessage(), e);
 			}
 		}
-	
+
 		// デバッグログ出力
 		m_log.debug("run end   : " + m_pollerGroup + "  " + m_pollerName);
 	}
 
 	private DataTable polling(
-			NodeInfo nodeInfo, 
-			HashMap<String, List<String>> pollingTargetMap, 
+			NodeInfo nodeInfo,
+			HashMap<String, List<String>> pollingTargetMap,
 			int retries,
 			int timeout){
 		DataTable dataTable = new DataTable();
 		DataTable tmpDataTable = null;
-		
+
 		// *****************************
 		// SNMPのpollerの設定
 		// *****************************
 		if(pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP) != null) {
-			SnmpPollerImpl poller = new SnmpPollerImpl();
-			
 			// joeSNMPではint型でSNMPのバージョンを定義
 			// 0:SNMP V1 protocol, 1:SNMP V2 protocol
 			int snmpVersionForJoeSNMP = 1;
@@ -522,41 +487,57 @@ public class PollingController {
 					if(version == -1){
 						version = 1;
 					}
-					
+
 					snmpVersionForJoeSNMP = version;
 				}
 			}
-				
-			tmpDataTable = poller.polling(
-					nodeInfo.getAvailableIpAddress(), 
-					nodeInfo.getSnmpPort(),
-					snmpVersionForJoeSNMP,
-					nodeInfo.getSnmpCommunity(),
-					retries == -1 ? nodeInfo.getSnmpRetryCount() : retries,
-					timeout == -1 ? nodeInfo.getSnmpTimeout() : timeout,
-					pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP), 
-					m_pollingConfig.isIndexCheckFlg());
+
+			if (snmpBulkFlag && "2c".equals(versionStr)) {
+				m_log.trace("SnmpBulkPoller version=" + versionStr);
+				SnmpBulkPollerImpl poller = new SnmpBulkPollerImpl();
+				tmpDataTable = poller.polling(
+						nodeInfo.getAvailableIpAddress(),
+						nodeInfo.getSnmpPort(),
+						snmpVersionForJoeSNMP,
+						nodeInfo.getSnmpCommunity(),
+						retries == -1 ? nodeInfo.getSnmpRetryCount() : retries,
+								timeout == -1 ? nodeInfo.getSnmpTimeout() : timeout,
+										pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP),
+										m_pollingConfig.isIndexCheckFlg());
+			} else {
+				m_log.trace("SnmpPoller version=" + versionStr);
+				SnmpPollerImpl poller = new SnmpPollerImpl();
+				tmpDataTable = poller.polling(
+						nodeInfo.getAvailableIpAddress(),
+						nodeInfo.getSnmpPort(),
+						snmpVersionForJoeSNMP,
+						nodeInfo.getSnmpCommunity(),
+						retries == -1 ? nodeInfo.getSnmpRetryCount() : retries,
+								timeout == -1 ? nodeInfo.getSnmpTimeout() : timeout,
+										pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP),
+										m_pollingConfig.isIndexCheckFlg());
+			}
 			dataTable.putAll(tmpDataTable);
 		}
-		
+
 		// *****************************
 		// WBEMのpollerの設定
 		// *****************************
 		if(pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_WBEM) != null) {
 			WbemPollerImpl poller = new WbemPollerImpl();
 			tmpDataTable = poller.polling(
-					nodeInfo.getAvailableIpAddress(), 
+					nodeInfo.getAvailableIpAddress(),
 					nodeInfo.getWbemPort(),
 					nodeInfo.getWbemProtocol(),
 					nodeInfo.getWbemUser(),
 					nodeInfo.getWbemUserPassword(),
 					nodeInfo.getWbemNameSpace(),
 					retries == -1 ? nodeInfo.getWbemRetryCount() : retries,
-					timeout == -1 ? nodeInfo.getWbemTimeout() : timeout,
-					pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_WBEM));
+							timeout == -1 ? nodeInfo.getWbemTimeout() : timeout,
+									pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_WBEM));
 			dataTable.putAll(tmpDataTable);
 		}
-		
+
 		// *****************************
 		// 仮想化のpollerの設定
 		//   プロトコルがSNMP,WBEM以外の場合(VMware,XENなど)は下記が処理される。
@@ -572,19 +553,19 @@ public class PollingController {
 			VmMethodMstLocal local = null;
 			try {
 				local = VmMethodMstUtil.getLocalHome().findByPrimaryKey(new VmMethodMstPK(
-					pollerProtocol, VmMethodTypeConstant.POLLERIMPL));
+						pollerProtocol, VmMethodTypeConstant.POLLERIMPL));
 			} catch (FinderException e) {
 				e.printStackTrace();
 			} catch (NamingException e) {
 				e.printStackTrace();
-			} 
+			}
 			if(local == null){
 				m_log.warn(pollerProtocol + " : Execution Class is not registered. (" +
 						VmMethodTypeConstant.POLLERIMPL +
-						")");
+				")");
 				continue;
 			}
-			
+
 			// pollerProtocolの実行クラス名をcc_vm_solution_mstから取得。
 			// 存在していない場合、中止。
 			String className = local.getClassName();
@@ -593,7 +574,7 @@ public class PollingController {
 				m_log.warn(pollerProtocol + " : Execution Class is not registered.");
 				continue;
 			}
-			
+
 			// コンストラクタの生成
 			// 失敗したら、中止。
 			Constructor pollerConstructor = null;
@@ -611,7 +592,7 @@ public class PollingController {
 				m_log.warn("action() : pollerConstructor is null");
 				continue;
 			}
-				
+
 			// ポーラーの取得。
 			// 取得できたら、ポーリング実行。
 			VmPollerImplInterface poller = null;
@@ -624,10 +605,10 @@ public class PollingController {
 				m_log.warn("action() : poller is null");
 				continue;
 			}
-			
+
 			String vmName = nodeInfo.getVmName();
 			m_log.debug("vmname : " + vmName);
-			
+
 			String vmNodeType = nodeInfo.getVirtualizationNodeType();
 			m_log.debug("vmNodeType : " + vmNodeType);
 
@@ -641,7 +622,7 @@ public class PollingController {
 					// ゲストノード用ポーリングパラメータを用いる
 					try {
 						targetNodeInfo = NodeProperty.getProperty(nodeInfo.getVmManagementNode());
-					} catch (FacilityNotFoundException e) {
+					} catch (FacilityNotFound e) {
 						m_log.warn("facility not found 3. FacilityId = " + m_targetFacilityId);
 						// ポーリングは実行しない
 						continue;
@@ -650,14 +631,7 @@ public class PollingController {
 			}
 
 			poller.init(pollerProtocol);
-			tmpDataTable = poller.polling(
-					nodeInfo.getAvailableIpAddress(),
-					nodeInfo.getVirtualizationNodeType(),
-					targetNodeInfo.getAvailableIpAddress(),
-					nodeInfo.getVmName(),
-					targetNodeInfo.getVmUser(),
-					targetNodeInfo.getVmUserPassword(),
-					targetNodeInfo.getVmProtocol(),
+			tmpDataTable = poller.polling(nodeInfo, targetNodeInfo,
 					pollingTargetMap.get(pollerProtocol));
 			dataTable.putAll(tmpDataTable);
 		}
@@ -673,16 +647,16 @@ public class PollingController {
 	public DataTable polling(HashMap<String, List<String>> targetMaps, int retries, int timeout){
 		// 各ポーラーで共通で使用するDataTableを定義する
 		DataTable dataTable = new DataTable();
-		
+
 		NodeInfo nodeInfo;
 		try {
 			nodeInfo = NodeProperty.getProperty(m_targetFacilityId);
-		} catch (FacilityNotFoundException e) {
+		} catch (FacilityNotFound e) {
 			m_log.warn("facility not found 4. FacilityId = " + m_targetFacilityId);
 			// ポーリングは実行しない
 			return dataTable;
 		}
-		
+
 		if(nodeInfo == null) {
 			m_log.warn("facility not found 5. FacilityId = " + nodeInfo.getFacilityId());
 			// ポーリングは実行しない
@@ -692,9 +666,9 @@ public class PollingController {
 			// ポーリングは実行しない
 			return dataTable;
 		}
-		
+
 		dataTable.putAll(polling(nodeInfo, targetMaps, retries, timeout));
-		
+
 		return dataTable;
 	}
 
@@ -702,19 +676,19 @@ public class PollingController {
 		try {
 			// 指定の値格納用テーブルが存在するか確認する
 			InitialContext ctx = new InitialContext();
-			
+
 			Object obj = ctx.lookup(SHARED_TABLE_JNDI_NAME);
 
-			SharedTable table = 
+			SharedTable table =
 				(SharedTable)PortableRemoteObject.narrow(obj, SharedTable.class);
-			
+
 			return table;
 		} catch (NamingException e) {
 			m_log.error(e.getMessage(), e);
 			throw e;
 		}
 	}
-	
+
 	/**
 	 * ポーラグループ名を返します。
 	 * @return ポーラグループ名
@@ -730,7 +704,7 @@ public class PollingController {
 	public String getPollerName() {
 		return m_pollerName;
 	}
-	
+
 	/**
 	 * ポーリング設定を返します。
 	 * @return ポーリング設定
