@@ -43,7 +43,8 @@ import org.opennms.protocols.snmp.SnmpSyntax;
 import org.opennms.protocols.snmp.SnmpUInt32;
 import org.opennms.protocols.snmp.SnmpVarBind;
 
-import com.clustercontrol.bean.PollerProtocolConstant;
+import com.clustercontrol.poller.bean.PollerProtocolConstant;
+import com.clustercontrol.repository.util.SearchNodeProperties;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.TableEntry;
 
@@ -54,17 +55,17 @@ import com.clustercontrol.sharedtable.TableEntry;
  * @since 3.0.0
  */
 public class SnmpPollerImpl implements SnmpHandler {
-	protected static Log m_log = LogFactory.getLog(SnmpPollerImpl.class);
+	private static Log m_log = LogFactory.getLog(SnmpPollerImpl.class);
 
 	// デフォルトのポート番号
 	private static final int DEFAULT_PORT = 161;
-	
+
 	// デフォルトのリトライ回数
 	private static final int DEFAULT_RETRIES = 3;
-	
+
 	// デフォルトのタイムアウト値(ms)
 	private static final int DEFAULT_TIMEOUT = 3000;
-	
+
 	// IPアドレス（ポーリングの度に更新）
 	private String m_ipAddress;
 
@@ -90,13 +91,13 @@ public class SnmpPollerImpl implements SnmpHandler {
 	// m_indexCheckFlg = true の場合に、取得できたVarBindの数が異なることで
 	// リトライした回数を保持（ポーリングの度に更新）
 	private int m_indexCheckVarBindSizeRetryCount = 0;
-	
+
 	// m_indexCheckFlg = true の場合にリトライした回数の合計を保持（ポーリングの度に更新）
 	private int m_indexCheckRetryCountTotal = 0;
-	
+
 	// m_indexCheckFlg = true の場合にリトライする回数の最大値
 	private final int MAX_RETRY_COUNT = 10;
-	
+
 	// ポーリング対象のスコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする
 	// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
 	//  プロセスのリストを最後まで取得できない場合があることへの対処）
@@ -106,6 +107,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 	// 最期にポーリングを行なった際のOIDのリスト m_indexCheckFlg = true の場合に使用する
 	private ArrayList<String> m_lastPollingOids;
+	
+	private boolean m_errorIgnoreFlg = false;
 
 	/**
 	 * アプリケーションスレッドがポーリング完了を待つためのラッチ。
@@ -114,7 +117,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 	 * 解放される。
 	 */
 	private final CountDownLatch latchPollingEnd = new CountDownLatch(1);
-	
+
 	enum PollerStatus {
 		/** まだこのポーラーが使用されていない状態<br>
 		 * POLLING/INTERNALにのみ状態遷移する。 */
@@ -140,7 +143,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 	 * この変数を読み書きする際には必ずlockModifyStatusのでガードが必要となる
 	 */
 	private PollerStatus pollerStatus = PollerStatus.NOUSING;
-	
+
 	/**
 	 * ポーラーのステータスを取得する。この関数はスレッドセーフではない。
 	 * 呼び出し側は、「lockModifyStatus」オブジェクトによって同期化処理が必要となる。
@@ -170,9 +173,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 			case COMPLETE:
 				return;
 			}
-			
+
 			pollerStatus = newStatus;
-			
+
 			// 新規ステータスが INTERNAL/TIMEOUT/RETRYOVER/COMPLETEの
 			// いずれかになるになる場合には、 ポーリング終了待ちのラッチを開放する
 			switch(pollerStatus) {
@@ -183,15 +186,15 @@ public class SnmpPollerImpl implements SnmpHandler {
 				latchPollingEnd.countDown();
 			}
 		}
-		
+
 	}
-	
+
 	/**
 	 * ポーラーのステータスを参照・更新変更する際に取得するロック。statusの
 	 * 読み書き・読んだ結果を基にアクションする際には必ずこのロックを取得する。
 	 */
 	private final Object lockModifyStatus = new Object();
-	
+
 	// クラス変数の初期化
 	private void init(){
 		m_indexCheckDiffIndexRetryCount = 0;
@@ -201,10 +204,10 @@ public class SnmpPollerImpl implements SnmpHandler {
 	}
 
 	/**
-	 * メインルーチン　
+	 * メインルーチン
 	 * IPアドレスと　DataTableを受け取り、
 	 * ポーリングした結果をDataTableに代入する
-	 *  
+	 * 
 	 * @param ipAddress IPアドレス
 	 * @param port ポート番号
 	 * @param version バージョン（0:SNMP V1 protocol, 1:SNMP V2 protocol）
@@ -215,22 +218,51 @@ public class SnmpPollerImpl implements SnmpHandler {
 	 * @param indexCheckFlg ポーリング結果のインデックスが揃っているかのチェック
 	 */
 	public DataTable polling(
-			String ipAddress, 
-			int port, 
+			String ipAddress,
+			int port,
 			int version,
-			String community, 
-			int retries, 
-			int timeout, 
+			String community,
+			int retries,
+			int timeout,
 			List<String> oidList,
 			boolean indexCheckFlg) {
+		return polling(ipAddress, port, version, community, retries, timeout, oidList, indexCheckFlg, false);
+	}
+	
+	/**
+	 * メインルーチン
+	 * IPアドレスと　DataTableを受け取り、
+	 * ポーリングした結果をDataTableに代入する
+	 * 
+	 * @param ipAddress IPアドレス
+	 * @param port ポート番号
+	 * @param version バージョン（0:SNMP V1 protocol, 1:SNMP V2 protocol）
+	 * @param community コミュニティ
+	 * @param retries １回のポーリングでのリトライ回数
+	 * @param timeout ポーリングのタイムアウト
+	 * @param oidList 対象OIDのリスト
+	 * @param indexCheckFlg ポーリング結果のインデックスが揃っているかのチェック
+	 * @param errorIgnoreFlg ポーリング時のエラーを無視するかのチェック
+	 */
+	public DataTable polling(
+			String ipAddress,
+			int port,
+			int version,
+			String community,
+			int retries,
+			int timeout,
+			List<String> oidList,
+			boolean indexCheckFlg,
+			boolean errorIgnoreFlg) {
 		// クラス変数を初期化
 		init();
 
 		// ポーリングの結果を返すインスタンス
 		m_dataTable = new DataTable();
-		
+
 		m_ipAddress = ipAddress;
 		m_indexCheckFlg = indexCheckFlg;
+		m_errorIgnoreFlg = errorIgnoreFlg;
 
 		// SnmpPeer の定義
 		SnmpPeer peer;
@@ -241,17 +273,17 @@ public class SnmpPollerImpl implements SnmpHandler {
 			return m_dataTable;
 		}
 		if (port < 0){
-			m_log.debug("set Port. " + port + " to " + DEFAULT_PORT);
+			m_log.trace("set Port. " + port + " to " + DEFAULT_PORT);
 			port = DEFAULT_PORT;
 		}
 
 		if (timeout < 0){
-			m_log.debug("set Timeout. " + timeout + " to " + DEFAULT_TIMEOUT);
+			m_log.trace("set Timeout. " + timeout + " to " + DEFAULT_TIMEOUT);
 			timeout = DEFAULT_TIMEOUT;
 		}
 
 		if (retries < 0){
-			m_log.debug("set Retries. " + retries + " to " + DEFAULT_RETRIES);
+			m_log.trace("set Retries. " + retries + " to " + DEFAULT_RETRIES);
 			retries = DEFAULT_RETRIES;
 		}
 
@@ -265,18 +297,19 @@ public class SnmpPollerImpl implements SnmpHandler {
 		parms.setVersion(version);
 		if (community != null)
 			parms.setReadCommunity(community);
-		
+
 		// デバッグ出力
-		if (m_log.isDebugEnabled()) {
-			m_log.debug("polling() start :" + ipAddress.toString());
-			m_log.debug("Port            : " + peer.getPort());
-			m_log.debug("Version         : " + peer.getParameters().getVersion());
-			m_log.debug("Community       : " + peer.getParameters().getReadCommunity());
-			m_log.debug("Retries         : " + peer.getRetries());
-			m_log.debug("Timeout         : " + peer.getTimeout());
-			m_log.debug("IndexCheckFlg   : " + indexCheckFlg);
+		if (m_log.isTraceEnabled()) {
+			m_log.trace("polling() start :" + ipAddress.toString());
+			m_log.trace("Port            : " + peer.getPort());
+			m_log.trace("Version         : " + peer.getParameters().getVersion());
+			m_log.trace("Community       : " + peer.getParameters().getReadCommunity());
+			m_log.trace("Retries         : " + peer.getRetries());
+			m_log.trace("Timeout         : " + peer.getTimeout());
+			m_log.trace("IndexCheckFlg   : " + indexCheckFlg);
+			m_log.trace("ErrorIgnoreFlg   : " + errorIgnoreFlg);
 		}
-		
+
 		// sessionを生成
 		SnmpSession session = null;
 		try {
@@ -302,7 +335,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 			Iterator<String> itr = oidList.iterator();
 			while (itr.hasNext()) {
-				m_oidText[i] = (String) itr.next();
+				m_oidText[i] = itr.next();
 
 				// OIDの最後が0で終わる場合は、.0を削除する
 				// GETNEXTで取得するため
@@ -331,7 +364,13 @@ public class SnmpPollerImpl implements SnmpHandler {
 			// ステータスをPOLLING中に変更し、実際にjoeSNMPに処理委譲する
 			setPollerStatus(PollerStatus.POLLING);
 			session.send(pdu);
-			m_log.debug("polling() : " + m_ipAddress + " send SnmpPduRequest");
+			if(m_log.isDebugEnabled()){
+				String str = "";
+				for (String s : m_oidText) {
+					str += s + ",";
+				}
+				m_log.debug("polling() : " + m_ipAddress + " send SnmpPduRequest, oid=" + str);
+			}
 			// SNMPの処理が完了（orエラーで失敗）するまで待つ。
 			latchPollingEnd.await();
 
@@ -346,10 +385,14 @@ public class SnmpPollerImpl implements SnmpHandler {
 				// テーブルに含まれているデータを全て削除する。
 				synchronized (lockModifyStatus) {
 					if (getPollerStatus() != PollerStatus.COMPLETE) {
-						m_dataTable.clear();
+						if(!m_errorIgnoreFlg){
+							m_dataTable.clear();
+						}else{
+							m_log.debug("polling() " + ipAddress.toString() + " error code " + getPollerStatus() + " is ignored");
+						}
 					}
 				}
-				
+
 				session.close();
 
 			} catch (Exception e) {
@@ -365,13 +408,15 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 		// リトライ回数が多い場合は出力する
 		if(m_indexCheckRetryCountTotal >= 100){
-			m_log.warn("polling():" + m_ipAddress + 
+			m_log.warn("polling():" + m_ipAddress +
 					" too many retries. count : " + m_indexCheckRetryCountTotal);
 		}
-		
+
 		// デバッグ出力
-		if (m_log.isDebugEnabled()) {
-			m_log.debug("polling() " + m_ipAddress + " retry total count : " + m_indexCheckRetryCountTotal);
+		if (m_log.isTraceEnabled()) {
+			m_log.trace("polling() " + m_ipAddress + " retry total count : " + m_indexCheckRetryCountTotal);
+		}
+		if(m_log.isDebugEnabled()){
 			m_log.debug("polling() end :" + ipAddress.toString());
 		}
 		return m_dataTable;
@@ -380,6 +425,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 	/**
 	 * SNMPポーリングの結果を受け取った際にコールバックされるメソッド
 	 */
+	@Override
 	public void snmpReceivedPdu(SnmpSession session, int cmd, SnmpPduPacket pdu) {
 		//		m_log.debug("snmpReceivedPdu() start");
 
@@ -403,16 +449,20 @@ public class SnmpPollerImpl implements SnmpHandler {
 				setPollerStatus(PollerStatus.INTERNAL);
 				return;
 			}
-			
+
 			if (req.getErrorStatus() != 0) {
 				String message = "polling() error :" + session.toString() +
-						", ErrorStatus=" + req.getErrorStatus();
+				", ErrorStatus=" + req.getErrorStatus();
 				if (req.getLength() != 0) {
 					message += ", oid=" + req.getVarBindAt(0).getName();
 				}
 				m_log.error(message);
 				setPollerStatus(PollerStatus.INTERNAL);
-				return;
+				if(!m_errorIgnoreFlg){
+					return;
+				}else{
+					m_log.trace("snmpReceivedPdu() error ignored");
+				}
 			}
 
 			// 次の pduを作成
@@ -435,7 +485,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 			// インデックスチェックが必要な場合は、この時点ではテーブルに反映することはできないため、
 			// 一時的にArrayListに保持する(m_indexCheckFlg = true の場合に使用)
 			ArrayList<TableEntry> entryBuffer = new ArrayList<TableEntry>(m_startOids.size());
-			
+
 			// pduの戻りとして帰ってきた SnmpVarBindを順次処理する
 			int length = pdu.getLength();
 			for (int i = 0; i < length; i++) {
@@ -446,12 +496,14 @@ public class SnmpPollerImpl implements SnmpHandler {
 				// 戻りの型が EndOfMibView の場合
 				// 停止条件のOIDにマッチした場合は終了
 				if (var.getValue().typeId() == SnmpEndOfMibView.ASNTYPE
-						|| ((m_stopOids.get(i) != null && m_stopOids.get(i).compare(var.getName()) < 0))) {
+						|| ((m_stopOids.get(i) != null &&
+								m_stopOids.get(i).compare(var.getName()) < 0))) {
 
 					// 該当OIDの収集を終了します
-					if (m_log.isDebugEnabled()) {
-						m_log.debug(m_ipAddress + " stop polling. " + i + ", "
-								+ m_startOids.get(i) + ", " + m_stopOids.get(i)
+					if (m_log.isTraceEnabled()) {
+						m_log.trace(m_ipAddress + " stop polling. " + i + ", "
+								+ m_startOids.get(i) + ", "
+								+ m_stopOids.get(i)
 								+ " - " + var.getName());
 					}
 					continue;
@@ -461,8 +513,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 				String oidString = var.getName().toString();
 
 				// デバッグ出力
-				if (m_log.isDebugEnabled()) {
-					m_log.debug("get " + m_ipAddress + " " + oidString + " "
+				if (m_log.isTraceEnabled()) {
+					m_log.trace("get " + m_ipAddress + " " + oidString + " "
 							+ time + " " + var.getValue().getClass().getName()
 							+ " " + var.getValue().toString());
 				}
@@ -470,9 +522,10 @@ public class SnmpPollerImpl implements SnmpHandler {
 				if (!m_startOids.get(i).isRootOf(var.getName())) {
 					// 帰ってきたMIB値のOIDが開始OIDのツリーの配下でない場合は、
 					// 該当OIDの収集を終了します
-					if (m_log.isDebugEnabled()) {
-						m_log.debug(m_ipAddress + " stop polling.. " + i + ", "
-								+ m_startOids.get(i) + ", " + m_stopOids.get(i)
+					if (m_log.isTraceEnabled()) {
+						m_log.trace(m_ipAddress + " stop polling.. " + i + ", "
+								+ m_startOids.get(i) + ", "
+								+ m_stopOids.get(i)
 								+ " - " + var.getName());
 					}
 					continue;
@@ -489,7 +542,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 							// OIDの最後のインデックスが一致しない場合
 							if (!lastIndexStr.equals(indexStr)) {
-								m_log.debug("Index not match. " + m_ipAddress
+								m_log.trace("Index not match. " + m_ipAddress
 										+ ", " + lastIndexStr + ", "
 										+ oidString);
 
@@ -504,20 +557,20 @@ public class SnmpPollerImpl implements SnmpHandler {
 					}
 
 					// デバッグ
-					if (m_log.isDebugEnabled()) {
-						m_log.debug("set " + m_ipAddress + ","
+					if (m_log.isTraceEnabled()) {
+						m_log.trace("set " + m_ipAddress + ","
 								+ oidString + "," + time + ","
 								+ var.getValue().toString() + ", "
 								+ var.getValue());
 					}
-					
+
 					if (var.getValue() instanceof SnmpUInt32) {
 						long longValue = ((SnmpUInt32)var.getValue()).getValue();
 						if(m_indexCheckFlg == true){
 							entryBuffer.add(new TableEntry(getEntryKey(oidString), time, longValue));
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + longValue);
 						} else {
@@ -527,9 +580,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 								}
 								m_dataTable.putValue(getEntryKey(oidString), time, longValue);
 							}
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + longValue);
 						}
@@ -537,9 +590,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 						long longValue = ((SnmpInt32)var.getValue()).getValue();
 						if(m_indexCheckFlg == true){
 							entryBuffer.add(new TableEntry(getEntryKey(oidString), time, longValue));
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + longValue);
 						} else {
@@ -549,9 +602,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 								}
 								m_dataTable.putValue(getEntryKey(oidString), time, longValue);
 							}
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + longValue);
 						}
@@ -561,9 +614,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 						long longValue = bigInt.longValue();
 						if(m_indexCheckFlg == true){
 							entryBuffer.add(new TableEntry(getEntryKey(oidString), time, longValue));
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + longValue);
 						} else {
@@ -573,33 +626,47 @@ public class SnmpPollerImpl implements SnmpHandler {
 								}
 								m_dataTable.putValue(getEntryKey(oidString), time, longValue);
 							}
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + longValue);
 						}
 					} else if (var.getValue() instanceof SnmpOctetString) {
-						// WindowsのNIC名の最終文字列には0x00がありPostgreSQLにINSERT不可なので除外する
 						byte[] stringBytes = ((SnmpOctetString)var.getValue()).getString();
 						String value = null;
-						if(stringBytes.length == 1 && stringBytes[stringBytes.length - 1] == 0x00){
+
+						if (oidString.startsWith(SearchNodeProperties.DEFAULT_OID_NIC_MAC_ADDRESS) && stringBytes.length == 6) {
+							// 6 byteのbinaryのOctetString
+							// 00:0A:1F:5F:30 という値として扱う
+							String hex = "";
 							value = "";
-						} else if(stringBytes.length > 1 && stringBytes[stringBytes.length - 1] == 0x00){
-							value = new String(stringBytes, 0 , stringBytes.length - 1);
+							for (int j = 0; j < stringBytes.length; j++) {
+								hex = String.format("%02x", stringBytes[j]).toUpperCase();
+								value += "".equals(value) ? hex : ":" + hex;
+							}
 						} else {
-							value = new String(stringBytes);
+							// WindowsのNIC名には0x00が含まれることがあるので除外する
+							int stringLen = stringBytes.length;
+							for (int j = 0; j < stringBytes.length; j++) {
+								if (stringBytes[j] == 0x00) {
+									stringLen = j;
+									break;
+								}
+							}
+							value = new String(stringBytes, 0 , stringLen);
 						}
-						if(m_log.isDebugEnabled()){
-							m_log.debug("SnmpOctetString getValue string = " + value);
+
+						if(m_log.isTraceEnabled()){
+							m_log.trace("SnmpOctetString getValue string = " + value);
 						}
-						
+
 						if(m_indexCheckFlg == true){
 							entryBuffer.add(new TableEntry(getEntryKey(oidString), time, value)
-									);
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+							);
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + value);
 						} else {
@@ -609,18 +676,18 @@ public class SnmpPollerImpl implements SnmpHandler {
 								}
 								m_dataTable.putValue(getEntryKey(oidString), time, value);
 							}
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + value);
 						}
 					} else {
 						if(m_indexCheckFlg == true){
 							entryBuffer.add(new TableEntry(getEntryKey(oidString), time, var.getValue()));
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + var.getValue().toString());
 						} else {
@@ -630,9 +697,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 								}
 								m_dataTable.putValue(getEntryKey(oidString), time, var.getValue());
 							}
-							
-							m_log.debug("snmpReceivedPdu() dataTable put : " +
-									"entryKey : " + getEntryKey(oidString) + 
+
+							m_log.trace("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + getEntryKey(oidString) +
 									", time : " + time +
 									", longValue : " + var.getValue().toString());
 						}
@@ -663,24 +730,24 @@ public class SnmpPollerImpl implements SnmpHandler {
 						}
 						while(itr.hasNext()){
 							TableEntry entry = itr.next();
-							
+
 							// デバッグ
-							if (m_log.isDebugEnabled()) {
-								m_log.debug("set (buffer to table) " + m_ipAddress + ","
+							if (m_log.isTraceEnabled()) {
+								m_log.trace("set (buffer to table) " + m_ipAddress + ","
 										+ entry.getKey() + "," + time + ","
 										+ entry.getValue().toString() + ", "
 										+ entry.getValue());
 							}
-							
+
 							m_dataTable.putValue(entry);
 						}
 					}
-					
+
 					// リトライ回数をリセット
 					m_indexCheckDiffIndexRetryCount = 0;
 					m_indexCheckVarBindSizeRetryCount = 0;
 				} else {
-					m_log.debug("detect error. " + m_ipAddress);
+					m_log.trace("detect error. " + m_ipAddress);
 				}
 
 				// 対応しているエラーパターン（VarBindの数をn個とする）
@@ -693,7 +760,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 					// ポーリング対象のスコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする
 					// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
 					//  プロセスのリストを最後まで取得できない場合があることへの対処）
-					
+
 					// リトライ回数をリセット
 					m_indexCheckDiffIndexRetryCount = 0;
 					m_indexCheckVarBindSizeRetryCount = 0;
@@ -707,12 +774,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 						// 対象スコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする。
 						// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
 						// プロセスのリストを最後まで取得できない場合があることへの対処）
-						if (m_log.isDebugEnabled()) {
-							m_log.debug("check retry. count="
+						if (m_log.isTraceEnabled()) {
+							m_log.trace("check retry. count="
 									+ m_indexCheckLastIndexRetryCount + " "
 									+ m_ipAddress);
 						}
-						
+
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
@@ -720,8 +787,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 						nxt.setRequestId(SnmpPduPacket.nextSequence());
 
 						for (int i = 0; i < m_lastPollingOids.size(); i++) {
-							if (m_log.isDebugEnabled()) {
-								m_log.debug("retry last polling set VarBind "
+							if (m_log.isTraceEnabled()) {
+								m_log.trace("retry last polling set VarBind "
 										+ m_ipAddress + ","
 										+ m_lastPollingOids.get(i));
 							}
@@ -740,12 +807,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 					// 次に実行するOIDが１つ以上ある場合
 
 					// ログ出力
-					if (m_log.isDebugEnabled()) {
+					if (m_log.isTraceEnabled()) {
 						if (m_indexCheckLastIndexRetryCount != 0) {
-							m_log.debug("detect error." + m_ipAddress);
+							m_log.trace("detect error." + m_ipAddress);
 						}
 					}
-					
+
 					// 最後のOIDでリトライ処理を実行した回数をリセット
 					m_indexCheckLastIndexRetryCount = 0;
 
@@ -753,8 +820,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 					// 再度ポーリングを実行する
 					if (maxIndex >= 0){  // エラーパターン2or3の対応
 						// ログ出力
-						if (m_log.isDebugEnabled()){
-							m_log.debug("recovery(index not match) " + m_ipAddress
+						if (m_log.isTraceEnabled()){
+							m_log.trace("recovery(index not match) " + m_ipAddress
 									+ "  max index:" + maxIndex
 									+ "  next VarBind size:" + lastPollingOids.size());
 						}
@@ -777,39 +844,39 @@ public class SnmpPollerImpl implements SnmpHandler {
 								nextStopOids.add(m_stopOids.get(i));
 								nxt.addVarBind(new SnmpVarBind(nextOid));
 								lastPollingOids.add(nextOid);
-							
+
 								// ログ出力
-								if (m_log.isDebugEnabled()) {
-									m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
+								if (m_log.isTraceEnabled()) {
+									m_log.trace("set VarBind " + m_ipAddress + "," + nextOid);
 								}
 							}
 						} else { // リトライ回数の上限を超えた場合
-							m_log.error("too many retries(index not match). " + m_ipAddress 
+							m_log.error("too many retries(index not match). " + m_ipAddress
 									+ " count:" + m_indexCheckDiffIndexRetryCount);
-							
+
 							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
 							// 終了を通知する。また、以降の処理は全てキャンセルする
 							setPollerStatus(PollerStatus.RETRYOVER);
 							return;
 						}
-						
+
 						// リトライ回数をカウントアップ
 						m_indexCheckDiffIndexRetryCount++;
 						m_indexCheckVarBindSizeRetryCount = 0;
 						m_indexCheckRetryCountTotal++;
 					} else if(lastPollingOids.size() != m_lastPollingOids.size()) {  // エラーパターン4の対応
 						// ログ出力
-						if (m_log.isDebugEnabled()){
-							m_log.debug("recovery(next count:" + lastPollingOids.size() + ") "
+						if (m_log.isTraceEnabled()){
+							m_log.trace("recovery(next count:" + lastPollingOids.size() + ") "
 									+ m_ipAddress);
 						}
-						
+
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
 						nxt = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
 						nxt.setRequestId(SnmpPduPacket.nextSequence());
-						
+
 						// 最大リトライ回数（デフォルト3回）までは、同じOIDでリトライ処理
 						// 永遠に同じOIDでリトライ処理が実行されないように、最大リトライ回数を超えたものは、
 						// IF文分岐の下のロジックを通る
@@ -821,22 +888,22 @@ public class SnmpPollerImpl implements SnmpHandler {
 								nextStopOids.add(m_stopOids.get(i));
 								nxt.addVarBind(new SnmpVarBind(nextOid));
 								lastPollingOids.add(nextOid);
-							
+
 								// ログ出力
-								if (m_log.isDebugEnabled()) {
-									m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
+								if (m_log.isTraceEnabled()) {
+									m_log.trace("set VarBind " + m_ipAddress + "," + nextOid);
 								}
 							}
 						} else { // リトライ回数の上限を超えた場合
-							m_log.error("too many retries(VarBind size not match). " + m_ipAddress 
+							m_log.error("too many retries(VarBind size not match). " + m_ipAddress
 									+ " count:" + m_indexCheckVarBindSizeRetryCount);
-							
+
 							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
 							// 終了を通知する。また、以降の処理は全てキャンセルする
 							setPollerStatus(PollerStatus.RETRYOVER);
 							return;
 						}
-							
+
 						// リトライ回数をカウントアップ
 						m_indexCheckDiffIndexRetryCount = 0;
 						m_indexCheckVarBindSizeRetryCount++;
@@ -863,11 +930,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 		}
 	}
 
-	/** 
+	/**
 	 * 内部エラー発生時にコールバックされるメソッド
 	 * 
 	 * @see org.opennms.protocols.snmp.SnmpHandler#snmpInternalError(org.opennms.protocols.snmp.SnmpSession, int, org.opennms.protocols.snmp.SnmpSyntax)
 	 */
+	@Override
 	public void snmpInternalError(SnmpSession session, int err, SnmpSyntax pdu) {
 		String message = "InternalError. The error code is " + err + ". IP:"
 		+ m_ipAddress + " OID:" + m_oidText[0];
@@ -881,11 +949,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 	 * ポーリングでタイムアウト発生時にコールバックされるメソッド
 	 * @see org.opennms.protocols.snmp.SnmpHandler#snmpTimeoutError(org.opennms.protocols.snmp.SnmpSession, org.opennms.protocols.snmp.SnmpSyntax)
 	 */
+	@Override
 	public void snmpTimeoutError(SnmpSession session, SnmpSyntax pdu) {
-//		m_log.warn("snmpTimeoutError():"
-//		+ session.getPeer().getPeer().toString() + " "
-//		+ ((SnmpPduRequest) pdu).toVarBindArray()[0].getName()
-//		+ " polling failed at TimeoutError");
+		//		m_log.warn("snmpTimeoutError():"
+		//		+ session.getPeer().getPeer().toString() + " "
+		//		+ ((SnmpPduRequest) pdu).toVarBindArray()[0].getName()
+		//		+ " polling failed at TimeoutError");
 
 		SnmpVarBind[] bind = ((SnmpPduRequest) pdu).toVarBindArray();
 		String ipAddress = session.getPeer().getPeer().toString();
@@ -913,11 +982,11 @@ public class SnmpPollerImpl implements SnmpHandler {
 	 * @param oidString OID
 	 */
 	private String getEntryKey(String oidString){
-		
+
 		return PollerProtocolConstant.PROTOCOL_SNMP + "." + oidString;
 	}
-	
-	
+
+
 	/**
 	 * 単体試験用
 	 * 
@@ -925,47 +994,114 @@ public class SnmpPollerImpl implements SnmpHandler {
 	 */
 	public static void main(String[] args) {
 		// パラメータを設定
-		String ipAddress = args[0];
+		String ipAddress = "172.26.98.158";
 
-		SnmpPollerImpl poller = new SnmpPollerImpl();
-		int port = Integer.parseInt(args[1]);
-		int version = Integer.parseInt(args[2]);
-		String comunity = args[3];
-		int retries = Integer.parseInt(args[4]);
-		int timeout = Integer.parseInt(args[5]);
-		boolean indexCheckFlg = Boolean.parseBoolean(args[6]);
+		int port = 161;
+		int version = 1;
+		String community = "public";
+		int retries = 3;
+		int timeout = 3000;
+		// boolean indexCheckFlg = false;
 		ArrayList<String> oids = new ArrayList<String>();
 
 		for(int i=7; i<args.length; i++){
 			oids.add(args[i]);
 		}
+		oids.clear();
+		oids.add(".1.3.6.1.2.1.2.2.1.10");
+		print(ipAddress, port, version, community, retries, timeout,
+				oids, false);
 
+		oids.clear();
+		oids.add(".1.3.6.1.2.1.2.2.1.10");
+		oids.add(".1.3.6.1.2.1.2.2.1.11");
+		oids.add(".1.3.6.1.2.1.2.2.1.14");
+		oids.add(".1.3.6.1.2.1.2.2.1.16");
+		oids.add(".1.3.6.1.2.1.2.2.1.17");
+		oids.add(".1.3.6.1.2.1.2.2.1.2");
+		oids.add(".1.3.6.1.2.1.2.2.1.20");
+		oids.add(".1.3.6.1.2.1.25.1.1");
+		oids.add(".1.3.6.1.2.1.25.2.3.1.3");
+		oids.add(".1.3.6.1.2.1.25.2.3.1.5");
+		oids.add(".1.3.6.1.2.1.25.2.3.1.6");
+		oids.add(".1.3.6.1.2.1.25.3.2.1.1");
+		oids.add(".1.3.6.1.2.1.25.3.3.1.2");
+		oids.add(".1.3.6.1.4.1.2021.10.1.5");
+		oids.add(".1.3.6.1.4.1.2021.11.3");
+		oids.add(".1.3.6.1.4.1.2021.11.4");
+		oids.add(".1.3.6.1.4.1.2021.11.50");
+		oids.add(".1.3.6.1.4.1.2021.11.51");
+		oids.add(".1.3.6.1.4.1.2021.11.52");
+		oids.add(".1.3.6.1.4.1.2021.11.53");
+		oids.add(".1.3.6.1.4.1.2021.11.54");
+		oids.add(".1.3.6.1.4.1.2021.11.59");
+		oids.add(".1.3.6.1.4.1.2021.11.60");
+		oids.add(".1.3.6.1.4.1.2021.11.62");
+		oids.add(".1.3.6.1.4.1.2021.11.63");
+		oids.add(".1.3.6.1.4.1.2021.13.15.1.1.2");
+		oids.add(".1.3.6.1.4.1.2021.13.15.1.1.3");
+		oids.add(".1.3.6.1.4.1.2021.13.15.1.1.4");
+		oids.add(".1.3.6.1.4.1.2021.13.15.1.1.5");
+		oids.add(".1.3.6.1.4.1.2021.13.15.1.1.6");
+		oids.add(".1.3.6.1.4.1.2021.4.11");
+		oids.add(".1.3.6.1.4.1.2021.4.14");
+		oids.add(".1.3.6.1.4.1.2021.4.15");
+		oids.add(".1.3.6.1.4.1.2021.4.3");
+		oids.add(".1.3.6.1.4.1.2021.4.4");
+		oids.add(".1.3.6.1.4.1.2021.4.5");
+		oids.add(".1.3.6.1.4.1.2021.4.6");
+		print(ipAddress, port, version, community, retries, timeout,
+				oids, false);
+
+		oids.clear();
+		oids.add(".1.3.6.1.2.1.25.4.2.1.2");
+		oids.add(".1.3.6.1.2.1.25.4.2.1.4");
+		oids.add(".1.3.6.1.2.1.25.4.2.1.5");
+		print(ipAddress, port, version, community, retries, timeout,
+				oids, true);
+	}
+	private static void print(String ipAddress, int port, int version, String community,
+			int retries, int timeout, ArrayList<String> oids, boolean indexCheckFlg) {
 		// ポーリングを行い値を収集
-		DataTable dataTable = poller.polling(
-				ipAddress, 
-				port,
-				version,
-				comunity,
-				retries,
-				timeout,
-				oids, 
-				indexCheckFlg);
+		try {
+			long start = System.currentTimeMillis();
+			SnmpPollerImpl poller = new SnmpPollerImpl();
+			DataTable dataTable = poller.polling(
+					ipAddress,
+					port,
+					version,
+					community,
+					retries,
+					timeout,
+					oids,
+					indexCheckFlg,
+					true);
+			long end = System.currentTimeMillis();
 
-		Set<String> keyset = dataTable.keySet();
-		// OID順に並び替える
-		TreeSet<String> keys = new TreeSet<String>(keyset);
-		Iterator<String> keyItr = keys.iterator();
+			Set<String> keyset = dataTable.keySet();
+			// OID順に並び替える
+			TreeSet<String> keys = new TreeSet<String>(keyset);
+			Iterator<String> keyItr = keys.iterator();
 
-		// テーブルの中の値を取得時刻順に並び替える
-		TreeSet<TableEntry> ts = new TreeSet<TableEntry>();
-		while(keyItr.hasNext()){
-			ts.add(dataTable.getValue(keyItr.next()));
-		}
+			// テーブルの中の値を取得時刻順に並び替える
+			TreeSet<TableEntry> ts = new TreeSet<TableEntry>();
+			while(keyItr.hasNext()){
+				ts.add(dataTable.getValue(keyItr.next()));
+			}
 
-		// 取得値の一覧を表示
-		Iterator<TableEntry> itr = ts.iterator();
-		while(itr.hasNext()){
-			m_log.info(itr.next());
+			// 取得値の一覧を表示
+			Iterator<TableEntry> itr = ts.iterator();
+			int i = 0;
+			while(itr.hasNext()){
+				TableEntry entry = itr.next();
+				m_log.info(entry);
+				System.out.println("tableEntry " + i + "," +  entry);
+				i++;
+			}
+			System.out.println("ts.size()=" + ts.size());
+			System.out.println("time = " + (end - start) + "ms " + poller.getClass().getSimpleName());
+		} catch (Exception e) {
+			e.printStackTrace();
 		}
 	}
 }
