@@ -30,13 +30,27 @@ AGENT_HOME="/opt/hinemos_agent"
 AGENT_INSTALL_SH="agent_installer_JP.sh"
 
 # Check on version
-VERSION=`rpm -q --qf "%{VERSION}" redhat-release`
-if [ $? -ne 0 ]; then
-    echo "The redhat-release package is not installed. Please install the redhat-release package."
+RELEASE_FILE="/etc/redhat-release"
+if [ -f $RELEASE_FILE ]; then
+    echo "The redhat-release file exist."
+else
+    echo "The redhat-release file does not exist. Please check file "$RELEASE_FILE
+    exit -1
+fi
+
+VERSION=""
+if [ `cat $RELEASE_FILE | grep 6.[0-9] | wc -l` -eq 1 ]; then
+    VERSION="rhel6"
+elif [ `cat $RELEASE_FILE | grep 5.[0-9] | wc -l` -eq 1 ]; then
+    VERSION="rhel5"
+elif [ `cat $RELEASE_FILE | grep 4.[0-9] | wc -l` -eq 1 ]; then
+    VERSION="rhel4"
+fi
+
+if [ "x"${VERSION} = "x" ]; then
+    echo "Red Hat Enterprise Linux may be ver 6 or 5 or 4"
     exit -1
 fi
-echo ${VERSION} | grep 4 > /dev/null && VERSION="rhel4"
-echo ${VERSION} | grep 5 > /dev/null && VERSION="rhel5"
 
 # Check on architecture
 ARCH=`rpm -q --qf "%{ARCH}" kernel`
@@ -172,10 +186,22 @@ esac
 ## Processing on Hinemos agent server
 ##
 
-# The Hinemos agent installer is copied from the server of input IP address. 
+# for IPv6's command format
+scp_address_mod=$scp_address
+if [ -n "`echo $scp_address_mod | awk /:/`" ]
+then
+    scp_address_mod="\[${scp_address}\]"
+fi
+mgr_address_mod=$mgr_address
+if [ -n "`echo $mgr_address_mod | awk /:/`" ]
+then
+    mgr_address_mod="\[${mgr_address}\]"
+fi
+
+# The Hinemos agent installer is copied from the server of input IP address.
 $EXPECT_PROC -c "
     set timeout -1
-    spawn $SCP_PROC root@${scp_address}:${agent}/${AGENT_PACKAGE} ${place}
+    spawn $SCP_PROC root@${scp_address_mod}:${agent}/${AGENT_PACKAGE} ${place}
     expect root
     send ${pass}\r
     expect eof
@@ -229,23 +255,9 @@ $EXPECT_PROC -c "
     send Y\r
 
 
-# Check on hosts file
-    expect {
-	-re \".*(Y.*\/ N.*\).*\" {send Y\r}
-	-re \".*OK.*\" {}
-	}
-
-# Check on rpm file
-
-    expect {
-	-re \".*\?\(Y\/N.*\).*\" {send Y\r}
-	-re \".*OK.*\" {}
-	}
-	
-
 # The manager's IP address setting
     expect -re \".*IP.*\"
-    send ${mgr_address}\r
+    send ${mgr_address_mod}\r
     expect -re \".*\(Y\/N.*\)\"
     send Y\r
 
@@ -253,9 +265,6 @@ $EXPECT_PROC -c "
     expect -re \".*\?\(Y\/N.*\).*\"
     send Y\r
 
-# Action in java installer
-    expect -re \".*Do you agree to the above license terms.*\"
-    send ${jre_ans}\r
 
 # "9" is selected by the menu selection displayed again. 
     expect -re \".*==>\"
