@@ -14,17 +14,6 @@ SET default_tablespace = '';
 
 SET default_with_oids = false;
 
---
--- Name: cc_acc_lock; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_acc_lock (
-    lock_id character varying(64) NOT NULL
-);
-
-
-ALTER TABLE public.cc_acc_lock OWNER TO hinemos;
-
 --
 -- Name: cc_cal_add_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -140,20 +129,6 @@ CREATE TABLE cc_cfg_node (
     platform_family character varying(128) NOT NULL,
     hardware_type character varying(128) NOT NULL,
     icon_image character varying(256) NOT NULL,
-    snmp_port integer NOT NULL,
-    snmp_community character varying(64) NOT NULL,
-    snmp_version character varying(8) NOT NULL,
-    snmp_timeout integer NOT NULL,
-    snmp_retry_count integer NOT NULL,
-    snmp_proxy character varying(512) NOT NULL,
-    wbem_user character varying(64) NOT NULL,
-    wbem_user_password character varying(64) NOT NULL,
-    wbem_port integer NOT NULL,
-    wbem_protocol character varying(32) NOT NULL,
-    wbem_timeout integer NOT NULL,
-    wbem_retry_count integer NOT NULL,
-    dhcp_client smallint NOT NULL,
-    ip_address_type integer NOT NULL,
     ip_address_version smallint NOT NULL,
     ip_address_v4 character varying(16) NOT NULL,
     ip_address_v6 character varying(40) NOT NULL,
@@ -162,6 +137,32 @@ CREATE TABLE cc_cfg_node (
     os_release character varying(256) NOT NULL,
     os_version character varying(256) NOT NULL,
     character_set character varying(16) NOT NULL,
+    snmp_port integer NOT NULL,
+    snmp_community character varying(64) NOT NULL,
+    snmp_version character varying(8) NOT NULL,
+    snmp_timeout integer NOT NULL,
+    snmp_retry_count integer NOT NULL,
+    wbem_user character varying(64) NOT NULL,
+    wbem_user_password character varying(64) NOT NULL,
+    wbem_port integer NOT NULL,
+    wbem_protocol character varying(32) NOT NULL,
+    wbem_timeout integer NOT NULL,
+    wbem_retry_count integer NOT NULL,
+    ipmi_ip_address character varying(1024) NOT NULL,
+    ipmi_port integer NOT NULL,
+    ipmi_user character varying(64) NOT NULL,
+    ipmi_user_password character varying(64) NOT NULL,
+    ipmi_timeout integer NOT NULL,
+    ipmi_retry_count integer NOT NULL,
+    ipmi_protocol character varying(32) NOT NULL,
+    ipmi_level character varying(32) NOT NULL,
+    winrm_user character varying(64) NOT NULL,
+    winrm_user_password character varying(64) NOT NULL,
+    winrm_version character varying(64) NOT NULL,
+    winrm_port integer NOT NULL,
+    winrm_protocol character varying(32) NOT NULL,
+    winrm_timeout integer NOT NULL,
+    winrm_retry_count integer NOT NULL,
     virtualization_node_type character varying(64) NOT NULL,
     vm_management_node character varying(64) NOT NULL,
     vm_index integer NOT NULL,
@@ -171,6 +172,10 @@ CREATE TABLE cc_cfg_node (
     vm_user character varying(64) NOT NULL,
     vm_user_password character varying(64) NOT NULL,
     vm_protocol character varying(32) NOT NULL,
+    vnet_switch_type character varying(64) NOT NULL,
+    vnet_host_node character varying(64) NOT NULL,
+    openflow_data_path_id character varying(1024) NOT NULL,
+    openflow_ctrl_ip_address character varying(1024) NOT NULL,
     administrator character varying(256) NOT NULL,
     contact character varying(1024) NOT NULL
 );
@@ -184,11 +189,12 @@ ALTER TABLE public.cc_cfg_node OWNER TO hinemos;
 
 CREATE TABLE cc_cfg_node_device (
     facility_id character varying(64) NOT NULL,
-    device_type character varying(32) NOT NULL,
     device_index integer NOT NULL,
+    device_type character varying(32) NOT NULL,
     device_name character varying(128) NOT NULL,
     device_display_name character varying(256) NOT NULL,
-    device_snmp_oid character varying(256) NOT NULL,
+    device_size integer NOT NULL,
+    device_size_unit character varying(64) NOT NULL,
     device_description character varying(1024) NOT NULL
 );
 
@@ -196,22 +202,111 @@ CREATE TABLE cc_cfg_node_device (
 ALTER TABLE public.cc_cfg_node_device OWNER TO hinemos;
 
 --
--- Name: cc_cfg_node_filesystem; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+-- Name: cc_cfg_node_cpu; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_cfg_node_cpu (
+    facility_id character varying(64) NOT NULL,
+    device_index integer NOT NULL,
+    device_type character varying(32) NOT NULL,
+    device_name character varying(128) NOT NULL,
+    device_display_name character varying(256) NOT NULL,
+    device_size integer NOT NULL,
+    device_size_unit character varying(64) NOT NULL,
+    device_description character varying(1024) NOT NULL
+);
+
+ALTER TABLE public.cc_cfg_node_cpu OWNER TO hinemos;
+
+--
+-- Name: cc_cfg_node_memory; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_cfg_node_memory (
+    facility_id character varying(64) NOT NULL,
+    device_index integer NOT NULL,
+    device_type character varying(32) NOT NULL,
+    device_name character varying(128) NOT NULL,
+    device_display_name character varying(256) NOT NULL,
+    device_size integer NOT NULL,
+    device_size_unit character varying(64) NOT NULL,
+    device_description character varying(1024) NOT NULL
+);
+
+
+ALTER TABLE public.cc_cfg_node_memory OWNER TO hinemos;
+
+--
+-- Name: cc_cfg_node_network_interface; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_cfg_node_network_interface (
+    facility_id character varying(64) NOT NULL,
+    device_index integer NOT NULL,
+    device_type character varying(32) NOT NULL,
+    device_name character varying(128) NOT NULL,
+    device_display_name character varying(256) NOT NULL,
+    device_size integer NOT NULL,
+    device_size_unit character varying(64) NOT NULL,
+    device_description character varying(1024) NOT NULL,
+    device_nic_ip_address character varying(1024) NOT NULL,
+    device_nic_mac_address character varying(1024) NOT NULL
+);
+
+
+ALTER TABLE public.cc_cfg_node_network_interface OWNER TO hinemos;
+
+--
+-- Name: cc_cfg_node_disk; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_cfg_node_disk (
+    facility_id character varying(64) NOT NULL,
+    device_index integer NOT NULL,
+    device_type character varying(32) NOT NULL,
+    device_name character varying(128) NOT NULL,
+    device_display_name character varying(256) NOT NULL,
+    device_size integer NOT NULL,
+    device_size_unit character varying(64) NOT NULL,
+    device_description character varying(1024) NOT NULL,
+    device_disk_rpm integer NOT NULL
+);
+
+
+ALTER TABLE public.cc_cfg_node_disk OWNER TO hinemos;
+
+--
+-- Name: cc_cfg_node_filesystem; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
 --
 
 CREATE TABLE cc_cfg_node_filesystem (
     facility_id character varying(64) NOT NULL,
-    fs_index integer NOT NULL,
-    fs_mount_point character varying(512) NOT NULL,
-    fs_display_name character varying(256) NOT NULL,
-    fs_type character varying(32) NOT NULL,
-    fs_snmp_oid character varying(1024) NOT NULL,
-    fs_description character varying(1024) NOT NULL
+    device_index integer NOT NULL,
+    device_type character varying(32) NOT NULL,
+    device_name character varying(128) NOT NULL,
+    device_display_name character varying(256) NOT NULL,
+    device_size integer NOT NULL,
+    device_size_unit character varying(64) NOT NULL,
+    device_description character varying(1024) NOT NULL,
+    device_filesystem_type character varying(64) NOT NULL
 );
 
 
 ALTER TABLE public.cc_cfg_node_filesystem OWNER TO hinemos;
 
+--
+-- Name: cc_cfg_node_variable; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_cfg_node_variable (
+    facility_id character varying(64) NOT NULL,
+    node_variable_name character varying(128) NOT NULL,
+    node_variable_value character varying(1024) NOT NULL
+);
+
+
+ALTER TABLE public.cc_cfg_node_variable OWNER TO hinemos;
+
 --
 -- Name: cc_cfg_node_hostname; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -307,36 +402,6 @@ CREATE TABLE cc_collector_category_mst (
 
 ALTER TABLE public.cc_collector_category_mst OWNER TO hinemos;
 
---
--- Name: cc_collector_device_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_collector_device_info (
-    collectorid character varying(256) NOT NULL,
-    facilityid character varying(64) NOT NULL,
-    display_name character varying(256) NOT NULL,
-    device_name character varying(256) NOT NULL,
-    index bigint,
-    device_id character varying(64),
-    device_type character varying(256)
-);
-
-
-ALTER TABLE public.cc_collector_device_info OWNER TO hinemos;
-
---
--- Name: cc_collector_item; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_collector_item (
-    collectorid character varying(256) NOT NULL,
-    item_code character varying(64) NOT NULL,
-    display_name character varying(256) NOT NULL
-);
-
-
-ALTER TABLE public.cc_collector_item OWNER TO hinemos;
-
 --
 -- Name: cc_collector_item_calc_method_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -402,74 +467,6 @@ CREATE TABLE cc_collector_polling_mst (
 
 ALTER TABLE public.cc_collector_polling_mst OWNER TO hinemos;
 
---
--- Name: cc_collector_profile; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_collector_profile (
-    collectorid character varying(256) NOT NULL,
-    collector_type smallint,
-    label character varying(1024),
-    scheduled_start_date timestamp without time zone,
-    scheduled_stop_date timestamp without time zone,
-    start_date timestamp without time zone,
-    stop_date timestamp without time zone,
-    target_facilityid character varying(64),
-    scope_path character varying(1024),
-    interval_sec integer,
-    period_min integer,
-    presave_period integer
-);
-
-
-ALTER TABLE public.cc_collector_profile OWNER TO hinemos;
-
---
--- Name: cc_collector_scope_relation; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_collector_scope_relation (
-    collectorid character varying(256) NOT NULL,
-    facilityid character varying(64) NOT NULL,
-    parent_facilityid character varying(64) NOT NULL
-);
-
-
-ALTER TABLE public.cc_collector_scope_relation OWNER TO hinemos;
-
---
--- Name: cc_collector_scope_snap; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_collector_scope_snap (
-    collectorid character varying(256) NOT NULL,
-    facilityid character varying(64) NOT NULL,
-    platform_id character varying(64) NOT NULL,
-    sub_platform_id character varying(64) NOT NULL,
-    facility_name character varying(256),
-    facility_type character varying(16)
-);
-
-
-ALTER TABLE public.cc_collector_scope_snap OWNER TO hinemos;
-
---
--- Name: cc_collector_status; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_collector_status (
-    collectorid character varying(256) NOT NULL,
-    run_status smallint,
-    error_status smallint,
-    end_status smallint,
-    count bigint,
-    last_collect_date timestamp without time zone
-)
-WITH (fillfactor=90);
-
-
-ALTER TABLE public.cc_collector_status OWNER TO hinemos;
-
 --
 -- Name: cc_crun_cmd_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -611,24 +608,13 @@ CREATE TABLE cc_crun_type_mst (
 
 ALTER TABLE public.cc_crun_type_mst OWNER TO hinemos;
 
---
--- Name: cc_device_type_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_device_type_mst (
-    device_type character varying(64) NOT NULL,
-    device_type_name character varying(256)
-);
-
-
-ALTER TABLE public.cc_device_type_mst OWNER TO hinemos;
-
 --
 -- Name: cc_event_log; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
 
 CREATE TABLE cc_event_log (
     monitor_id character varying(64) NOT NULL,
+    monitor_detail_id character varying(1024) NOT NULL,
     plugin_id character varying(64) NOT NULL,
     generation_date timestamp without time zone NOT NULL,
     facility_id character varying(64) NOT NULL,
@@ -643,7 +629,10 @@ CREATE TABLE cc_event_log (
     confirm_user character varying(64),
     duplication_count bigint NOT NULL,
     output_date timestamp without time zone NOT NULL,
-    inhibited_flg smallint NOT NULL
+    inhibited_flg smallint NOT NULL,
+    comment_date timestamp without time zone,
+    comment_user character varying(64),
+    comment character varying(2048) NOT NULL
 );
 
 
@@ -655,6 +644,7 @@ ALTER TABLE public.cc_event_log OWNER TO hinemos;
 
 CREATE TABLE cc_event_multi_info (
     monitor_id character varying(64) NOT NULL,
+    monitor_detail_id character varying(1024) NOT NULL,
     plugin_id character varying(64) NOT NULL,
     facility_id character varying(64) NOT NULL,
     output_date timestamp without time zone NOT NULL,
@@ -1150,39 +1140,6 @@ CREATE TABLE cc_job_user_relation_mst (
 
 ALTER TABLE public.cc_job_user_relation_mst OWNER TO hinemos;
 
---
--- Name: cc_log_transfer_file_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_log_transfer_file_info (
-    transfer_id character varying(64) NOT NULL,
-    file_path character varying(4096) NOT NULL,
-    run_interval smallint,
-    existence_flg smallint,
-    valid_flg smallint NOT NULL
-);
-
-
-ALTER TABLE public.cc_log_transfer_file_info OWNER TO hinemos;
-
---
--- Name: cc_log_transfer_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_log_transfer_info (
-    transfer_id character varying(64) NOT NULL,
-    description character varying(256),
-    facility_id character varying(64),
-    valid_flg smallint NOT NULL,
-    reg_date timestamp without time zone,
-    update_date timestamp without time zone,
-    reg_user character varying(64),
-    update_user character varying(64)
-);
-
-
-ALTER TABLE public.cc_log_transfer_info OWNER TO hinemos;
-
 --
 -- Name: cc_mail_template_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -1264,26 +1221,12 @@ CREATE TABLE cc_map_position (
 
 ALTER TABLE public.cc_map_position OWNER TO hinemos;
 
---
--- Name: cc_monitor_agent_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_monitor_agent_info (
-    monitor_type_id character varying(64) NOT NULL,
-    monitor_id character varying(64) NOT NULL,
-    check_job_agent smallint,
-    check_log_agent smallint
-);
-
-
-ALTER TABLE public.cc_monitor_agent_info OWNER TO hinemos;
 
 --
 -- Name: cc_monitor_http_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
 
 CREATE TABLE cc_monitor_http_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     request_url character varying(2083) NOT NULL,
     url_replace smallint,
@@ -1296,30 +1239,62 @@ CREATE TABLE cc_monitor_http_info (
 
 ALTER TABLE public.cc_monitor_http_info OWNER TO hinemos;
 
+
+--
+-- Name: cc_monitor_custom_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE cc_monitor_custom_info (
+    monitor_id character varying(64) NOT NULL,
+    execute_type smallint NOT NULL,
+    selected_facility_id character varying(64) DEFAULT NULL,
+    effective_user character varying(64) NOT NULL,
+    command character varying(1024) NOT NULL, 
+    timeout smallint NOT NULL
+);
+
+
+ALTER TABLE public.cc_monitor_custom_info OWNER TO hinemos;
+
+
+--
+-- Name: cc_monitor_logfile_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE cc_monitor_logfile_info (
+    monitor_id character varying(64) NOT NULL,
+    logfile character varying(1024) NOT NULL
+);
+
+
+ALTER TABLE public.cc_monitor_logfile_info OWNER TO hinemos;
+
+
 --
 -- Name: cc_monitor_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
 
 CREATE TABLE cc_monitor_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
+    monitor_type_id character varying(64) NOT NULL,
     monitor_type smallint NOT NULL,
     description character varying(256),
     facility_id character varying(64),
     run_interval smallint,
+    delay_time integer,
+    trigger_type character varying(64),
     calendar_id character varying(64),
-    monitor_block smallint,
-    determination_id character varying(64),
     failure_priority smallint,
     notify_group_id character varying(1024),
     application character varying(64),
-    failure_message_id character varying(64),
-    failure_message character varying(256),
+    monitor_flg smallint,
+    collector_flg smallint,
+    item_name character varying(64),
+    measure character varying(64),
     reg_date timestamp without time zone,
     update_date timestamp without time zone,
     reg_user character varying(64),
-    update_user character varying(64),
-    timeout smallint
+    update_user character varying(64)
 );
 
 
@@ -1330,7 +1305,6 @@ ALTER TABLE public.cc_monitor_info OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_numeric_value_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     priority smallint NOT NULL,
     threshold_upper_limit double precision NOT NULL,
@@ -1347,13 +1321,10 @@ ALTER TABLE public.cc_monitor_numeric_value_info OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_perf_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
-    collector_id character varying(256),
-    item_code character varying(256),
-    device_index bigint,
-    device_name character varying(256) NOT NULL,
-    display_name character varying(256)
+    item_code character varying(256) NOT NULL,
+    device_display_name character varying(256) NOT NULL,
+    breakdown_flg smallint NOT NULL
 );
 
 
@@ -1364,7 +1335,6 @@ ALTER TABLE public.cc_monitor_perf_info OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_ping_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     run_count smallint,
     run_interval smallint,
@@ -1379,7 +1349,6 @@ ALTER TABLE public.cc_monitor_ping_info OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_port_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     port_number integer,
     run_count smallint,
@@ -1396,7 +1365,6 @@ ALTER TABLE public.cc_monitor_port_info OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_process_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     command character varying(256) NOT NULL,
     param character varying(256)
@@ -1454,12 +1422,8 @@ ALTER TABLE public.cc_monitor_protocol_mst OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_snmp_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
-    community_name character varying(64) NOT NULL,
-    snmp_port integer NOT NULL,
     snmp_oid character varying(1024) NOT NULL,
-    snmp_version character varying(64) NOT NULL,
     convert_flg smallint NOT NULL
 );
 
@@ -1485,7 +1449,6 @@ ALTER TABLE public.cc_monitor_snmp_value OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_sql_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     connection_url character varying(256) NOT NULL,
     connection_user character varying(64) NOT NULL,
@@ -1505,6 +1468,7 @@ CREATE TABLE cc_monitor_status (
     facility_id character varying(64) NOT NULL,
     plugin_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
+    sub_key text NOT NULL,
     priority smallint NOT NULL,
     last_update timestamp without time zone NOT NULL,
     counter bigint NOT NULL
@@ -1518,28 +1482,61 @@ ALTER TABLE public.cc_monitor_status OWNER TO hinemos;
 --
 
 CREATE TABLE cc_monitor_string_value_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     order_no smallint NOT NULL,
     description character varying(256),
     process_type smallint NOT NULL,
     pattern character varying(1024) NOT NULL,
     priority smallint NOT NULL,
-    message_id character varying(64),
     message character varying(256),
-    notify_group_id character varying(1024),
+    case_sensitivity_flg smallint NOT NULL,
     valid_flg smallint NOT NULL
 );
 
 
 ALTER TABLE public.cc_monitor_string_value_info OWNER TO hinemos;
 
+--
+-- Name: cc_monitor_trap_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_monitor_trap_info (
+    monitor_id character varying(64),
+    community_name character varying(64),
+    check_mode smallint,
+    community_check smallint,
+    charset_convert smallint,
+    charset_name character varying(64)
+);
+
+
+ALTER TABLE public.cc_monitor_trap_info OWNER TO hinemos;
+
+--
+-- Name: cc_monitor_trap_value_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_monitor_trap_value_info (
+    monitor_id character varying(64),
+    mib character varying(1024),
+    trap_oid character varying(1024),
+    generic_id smallint,
+    specific_id integer,
+    uei text,
+    valid_flg smallint,
+    priority smallint,
+    logmsg text,
+    descr text
+);
+
+
+ALTER TABLE public.cc_monitor_trap_value_info OWNER TO hinemos;
+
 --
 -- Name: cc_monitor_truth_value_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
 
 CREATE TABLE cc_monitor_truth_value_info (
-    monitor_type_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     priority smallint NOT NULL,
     truth_value smallint NOT NULL,
@@ -1550,6 +1547,18 @@ CREATE TABLE cc_monitor_truth_value_info (
 
 ALTER TABLE public.cc_monitor_truth_value_info OWNER TO hinemos;
 
+--
+-- Name: cc_monitor_winservice_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_monitor_winservice_info (
+    monitor_id character varying(64) NOT NULL,
+    service_name character varying(1024) NOT NULL
+);
+
+
+ALTER TABLE public.cc_monitor_winservice_info OWNER TO hinemos;
+
 --
 -- Name: cc_notify_command_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -1590,6 +1599,8 @@ CREATE TABLE cc_notify_history (
     plugin_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
     notify_id character varying(64) NOT NULL,
+    sub_key text NOT NULL,
+    priority smallint NOT NULL,
     last_notify timestamp without time zone NOT NULL
 );
 
@@ -1699,23 +1710,6 @@ CREATE TABLE cc_notify_status_info (
 
 ALTER TABLE public.cc_notify_status_info OWNER TO hinemos;
 
---
--- Name: cc_notify_type_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_notify_type_mst (
-    notify_type smallint NOT NULL,
-    notify_name_key character varying(256) NOT NULL,
-    queue_name character varying(64) NOT NULL,
-    use_jms smallint,
-    use_jta smallint,
-    action_class_name character varying(256),
-    dialog_class_name character varying(256)
-);
-
-
-ALTER TABLE public.cc_notify_type_mst OWNER TO hinemos;
-
 --
 -- Name: cc_priority_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -1747,29 +1741,6 @@ CREATE TABLE cc_priority_info (
 
 ALTER TABLE public.cc_priority_info OWNER TO hinemos;
 
---
--- Name: cc_snmp_trap_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_snmp_trap_info (
-    monitor_id character varying(64) NOT NULL,
-    description character varying(256),
-    facility_id character varying(64),
-    community_name character varying(64),
-    notify_group_id character varying(1024),
-    application character varying(64),
-    valid_flg smallint NOT NULL,
-    calendar_id character varying(64),
-    reg_date timestamp without time zone,
-    update_date timestamp without time zone,
-    reg_user character varying(64),
-    update_user character varying(64),
-    check_mode smallint
-);
-
-
-ALTER TABLE public.cc_snmp_trap_info OWNER TO hinemos;
-
 --
 -- Name: cc_snmp_trap_mib_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -1805,39 +1776,6 @@ CREATE TABLE cc_snmp_trap_mst (
 
 ALTER TABLE public.cc_snmp_trap_mst OWNER TO hinemos;
 
---
--- Name: cc_snmp_trap_notify_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_snmp_trap_notify_info (
-    monitor_id character varying(64) NOT NULL,
-    notify_id character varying(64) NOT NULL,
-    notify_type smallint,
-    notify_flg smallint
-);
-
-
-ALTER TABLE public.cc_snmp_trap_notify_info OWNER TO hinemos;
-
---
--- Name: cc_snmp_trap_oid_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_snmp_trap_oid_info (
-    monitor_id character varying(64) NOT NULL,
-    mib character varying(1024) NOT NULL,
-    trap_oid character varying(1024) NOT NULL,
-    generic_id smallint NOT NULL,
-    specific_id integer NOT NULL,
-    valid_flg smallint,
-    priority smallint,
-    logmsg text,
-    descr text
-);
-
-
-ALTER TABLE public.cc_snmp_trap_oid_info OWNER TO hinemos;
-
 --
 -- Name: cc_snmp_value_type_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -1856,6 +1794,7 @@ ALTER TABLE public.cc_snmp_value_type_mst OWNER TO hinemos;
 CREATE TABLE cc_status_info (
     facility_id character varying(64) NOT NULL,
     monitor_id character varying(64) NOT NULL,
+    monitor_detail_id character varying(1024) NOT NULL,
     plugin_id character varying(64) NOT NULL,
     application character varying(64) NOT NULL,
     message_id character varying(64) NOT NULL,
@@ -1870,33 +1809,6 @@ CREATE TABLE cc_status_info (
 
 ALTER TABLE public.cc_status_info OWNER TO hinemos;
 
---
--- Name: cc_syslog_monitor_rule; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE cc_syslog_monitor_rule (
-    order_no smallint NOT NULL,
-    description character varying(256),
-    facility_id character varying(64),
-    pattern character varying(1024),
-    process_type smallint NOT NULL,
-    priority smallint NOT NULL,
-    monitor_id character varying(64),
-    application character varying(64),
-    message_id character varying(64),
-    message character varying(256),
-    notify_group_id character varying(1024),
-    calendar_id character varying(64),
-    valid_flg smallint NOT NULL,
-    reg_date timestamp without time zone,
-    update_date timestamp without time zone,
-    reg_user character varying(64),
-    update_user character varying(64)
-);
-
-
-ALTER TABLE public.cc_syslog_monitor_rule OWNER TO hinemos;
-
 --
 -- Name: cc_system_notify_event_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -2001,16 +1913,206 @@ CREATE TABLE cc_vm_solution_mst (
 ALTER TABLE public.cc_vm_solution_mst OWNER TO hinemos;
 
 --
--- Name: maintenance_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+-- Name: hilosequences; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
 
-CREATE TABLE maintenance_info (
+CREATE TABLE hilosequences (
+    sequencename character varying(50) NOT NULL,
+    highvalues integer NOT NULL
+);
+
+
+ALTER TABLE public.hilosequences OWNER TO hinemos;
+
+--
+-- Name: jbm_counter; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_counter (
+    name character varying(255) NOT NULL,
+    next_id bigint
+);
+
+
+ALTER TABLE public.jbm_counter OWNER TO hinemos;
+
+--
+-- Name: jbm_dual; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_dual (
+    dummy integer NOT NULL
+);
+
+
+ALTER TABLE public.jbm_dual OWNER TO hinemos;
+
+--
+-- Name: jbm_id_cache; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_id_cache (
+    node_id integer NOT NULL,
+    cntr integer NOT NULL,
+    jbm_id character varying(255)
+);
+
+
+ALTER TABLE public.jbm_id_cache OWNER TO hinemos;
+
+--
+-- Name: jbm_msg; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_msg (
+    message_id bigint NOT NULL,
+    reliable character(1),
+    expiration bigint,
+    "timestamp" bigint,
+    priority smallint,
+    type smallint,
+    headers bytea,
+    payload bytea
+);
+
+
+ALTER TABLE public.jbm_msg OWNER TO hinemos;
+
+--
+-- Name: jbm_msg_ref; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_msg_ref (
+    message_id bigint NOT NULL,
+    channel_id bigint NOT NULL,
+    transaction_id bigint,
+    state character(1),
+    ord bigint,
+    page_ord bigint,
+    delivery_count integer,
+    sched_delivery bigint
+);
+
+
+ALTER TABLE public.jbm_msg_ref OWNER TO hinemos;
+
+--
+-- Name: jbm_postoffice; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_postoffice (
+    postoffice_name character varying(255) NOT NULL,
+    node_id integer NOT NULL,
+    queue_name character varying(255) NOT NULL,
+    cond character varying(1023),
+    selector character varying(1023),
+    channel_id bigint,
+    clustered character(1),
+    all_nodes character(1)
+);
+
+
+ALTER TABLE public.jbm_postoffice OWNER TO hinemos;
+
+--
+-- Name: jbm_role; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_role (
+    role_id character varying(32) NOT NULL,
+    user_id character varying(32) NOT NULL
+);
+
+
+ALTER TABLE public.jbm_role OWNER TO hinemos;
+
+--
+-- Name: jbm_tx; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_tx (
+    node_id integer,
+    transaction_id bigint NOT NULL,
+    branch_qual bytea,
+    format_id integer,
+    global_txid bytea
+);
+
+
+ALTER TABLE public.jbm_tx OWNER TO hinemos;
+
+--
+-- Name: jbm_user; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jbm_user (
+    user_id character varying(32) NOT NULL,
+    passwd character varying(32) NOT NULL,
+    clientid character varying(128)
+);
+
+
+ALTER TABLE public.jbm_user OWNER TO hinemos;
+
+--
+-- Name: jms_message_log; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jms_message_log (
+    messageid integer NOT NULL,
+    destination character varying(255) NOT NULL,
+    txid integer,
+    txop character(1),
+    lateclone character(1),
+    messageblob bytea
+);
+
+
+ALTER TABLE public.jms_message_log OWNER TO hinemos;
+
+--
+-- Name: jms_reference_log; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jms_reference_log (
+    messageid integer NOT NULL,
+    destination character varying(256) NOT NULL,
+    txid integer,
+    txop character(1),
+    redelivered character(1),
+    redelivers integer
+);
+
+
+ALTER TABLE public.jms_reference_log OWNER TO hinemos;
+
+--
+-- Name: jms_transaction_log; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE jms_transaction_log (
+    txid integer
+);
+
+
+ALTER TABLE public.jms_transaction_log OWNER TO hinemos;
+
+--
+-- Name: cc_maintenance_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+--
+
+CREATE TABLE cc_maintenance_info (
     maintenance_id character varying(64) NOT NULL,
     description character varying(256),
     type_id character varying(64) NOT NULL,
-    keep_id character varying(64),
+    data_retention_period smallint,
     calendar_id character varying(64),
-    schedule_date timestamp without time zone,
+    schedule_type int NOT NULL,
+    month int,
+    day int,
+    week int,
+    hour int,
+    minute int NOT NULL,
     notify_group_id character varying(1024),
     application character varying(64),
     valid_flg smallint NOT NULL,
@@ -2021,33 +2123,20 @@ CREATE TABLE maintenance_info (
 );
 
 
-ALTER TABLE public.maintenance_info OWNER TO hinemos;
+ALTER TABLE public.cc_maintenance_info OWNER TO hinemos;
 
 --
--- Name: maintenance_keep_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+-- Name: cc_maintenance_type_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
 
-CREATE TABLE maintenance_keep_mst (
-    keep_id character varying(64) NOT NULL,
-    name_id character varying(256) NOT NULL,
-    order_no smallint NOT NULL
-);
-
-
-ALTER TABLE public.maintenance_keep_mst OWNER TO hinemos;
-
---
--- Name: maintenance_type_mst; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE maintenance_type_mst (
+CREATE TABLE cc_maintenance_type_mst (
     type_id character varying(64) NOT NULL,
     name_id character varying(256) NOT NULL,
     order_no smallint NOT NULL
 );
 
 
-ALTER TABLE public.maintenance_type_mst OWNER TO hinemos;
+ALTER TABLE public.cc_maintenance_type_mst OWNER TO hinemos;
 
 --
 -- Name: qrtz_blob_triggers; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
@@ -2223,170 +2312,15 @@ CREATE TABLE qrtz_triggers (
     start_time bigint NOT NULL,
     end_time bigint,
     calendar_name character varying(80),
-    misfire_instr smallint
+    misfire_instr smallint,
+    job_data bytea
 );
 
 
 ALTER TABLE public.qrtz_triggers OWNER TO hinemos;
 
 --
--- Name: public; Type: ACL; Schema: -; Owner: hinemos
---
-
-REVOKE ALL ON SCHEMA public FROM PUBLIC;
-REVOKE ALL ON SCHEMA public FROM hinemos;
-GRANT ALL ON SCHEMA public TO hinemos;
-GRANT ALL ON SCHEMA public TO PUBLIC;
-
-
---
--- JBoss Remoting/Messaging Schema
---
-
-
---
--- Name: jbm_counter; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_counter (
-    name character varying(255) NOT NULL,
-    next_id bigint
-);
-
-
-ALTER TABLE public.jbm_counter OWNER TO hinemos;
-
---
--- Name: jbm_dual; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_dual (
-    dummy integer NOT NULL
-);
-
-
-ALTER TABLE public.jbm_dual OWNER TO hinemos;
-
---
--- Name: jbm_id_cache; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_id_cache (
-    node_id integer NOT NULL,
-    cntr integer NOT NULL,
-    jbm_id character varying(255)
-);
-
-ALTER TABLE public.jbm_id_cache OWNER TO hinemos;
-
---
--- Name: jbm_msg; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_msg (
-    message_id bigint NOT NULL,
-    reliable character(1),
-    expiration bigint,
-    "timestamp" bigint,
-    priority smallint,
-    type smallint,
-    headers bytea,
-    payload bytea
-);
-
-
-ALTER TABLE public.jbm_msg OWNER TO hinemos;
-
---
--- Name: jbm_msg_ref; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_msg_ref (
-    message_id bigint NOT NULL,
-    channel_id bigint NOT NULL,
-    transaction_id bigint,
-    state character(1),
-    ord bigint,
-    page_ord bigint,
-    delivery_count integer,
-    sched_delivery bigint
-);
-
-
-ALTER TABLE public.jbm_msg_ref OWNER TO hinemos;
-
---
--- Name: jbm_postoffice; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_postoffice (
-    postoffice_name character varying(255) NOT NULL,
-    node_id integer NOT NULL,
-    queue_name character varying(255) NOT NULL,
-    cond character varying(1023),
-    selector character varying(1023),
-    channel_id bigint,
-    clustered character(1),
-    all_nodes character(1)
-);
-
-
-ALTER TABLE public.jbm_postoffice OWNER TO hinemos;
-
---
--- Name: jbm_role; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_role (
-    role_id character varying(32) NOT NULL,
-    user_id character varying(32) NOT NULL
-);
-
-
-ALTER TABLE public.jbm_role OWNER TO hinemos;
-
---
--- Name: jbm_tx; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_tx (
-    node_id integer,
-    transaction_id bigint NOT NULL,
-    branch_qual bytea,
-    format_id integer,
-    global_txid bytea
-);
-
-
-ALTER TABLE public.jbm_tx OWNER TO hinemos;
-
---
--- Name: jbm_tx_ex; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_tx_ex (
-    transaction_id bigint NOT NULL,
-    start_time bigint
-);
-
-
-ALTER TABLE public.jbm_tx_ex OWNER TO hinemos;
-
---
--- Name: jbm_user; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
---
-
-CREATE TABLE jbm_user (
-    user_id character varying(32) NOT NULL,
-    passwd character varying(32) NOT NULL,
-    clientid character varying(128)
-);
-
-
-ALTER TABLE public.jbm_user OWNER TO hinemos;
-
---
--- Name: timers; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+-- Name: timers; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
 
 CREATE TABLE timers (
@@ -2401,6 +2335,42 @@ CREATE TABLE timers (
 
 ALTER TABLE public.timers OWNER TO hinemos;
 
+--
+-- Name: cc_job_schedule; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE cc_job_schedule (
+    schedule_id character varying(64) NOT NULL,
+    schedule_name character varying(64) NOT NULL,
+    jobunit_id character varying(64) NOT NULL,
+    job_id character varying(64) NOT NULL,
+    calendar_id character varying(64),
+    schedule_type int NOT NULL,
+    month int,
+    day int,
+    week int,
+    hour int,
+    minute int NOT NULL,
+    valid_flg smallint NOT NULL,
+    reg_date timestamp without time zone,
+    update_date timestamp without time zone,
+    reg_user character varying(64),
+    update_user character varying(64)
+);
+
+
+ALTER TABLE public.cc_job_schedule OWNER TO hinemos;
+
+
+--
+-- Name: public; Type: ACL; Schema: -; Owner: hinemos
+--
+
+REVOKE ALL ON SCHEMA public FROM PUBLIC;
+REVOKE ALL ON SCHEMA public FROM hinemos;
+GRANT ALL ON SCHEMA public TO hinemos;
+GRANT ALL ON SCHEMA public TO PUBLIC;
+
 
 --
 -- PostgreSQL database dump complete
