@@ -434,6 +434,13 @@ ${PSQLCMD} -c "
         idx_blks_read + idx_blks_hit DESC
 " | tee -a ${SUMMARY_FILE}
 
+## txid_current
+echo "### txid_current ###" | tee -a ${SUMMARY_FILE}
+${PSQLCMD} -c "
+    SELECT
+        txid_current()
+" | tee -a ${SUMMARY_FILE}
+
 
 
 }
